# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: keyphrase_boosting.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18keyphrase_boosting.proto\x12\x12keyphrase_boosting\x1a\x1fgoogle/protobuf/timestamp.proto\"X\n\x12KeyphrasesBoosting\x12\x42\n\x13keyphrases_boosting\x18\x01 \x03(\x0b\x32%.keyphrase_boosting.KeyphraseBoosting\"\xf1\x01\n\x11KeyphraseBoosting\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tkeyphrase\x18\x02 \x01(\t\x12\r\n\x05level\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x05 \x01(\t\x12\x33\n\nupdated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x12\x17\n\nupdated_by\x18\x07 \x01(\tH\x01\x88\x01\x01\x42\r\n\x0b_updated_atB\r\n\x0b_updated_by\"Q\n!KeyphraseBoosting_CreateKeyphrase\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tkeyphrase\x18\x02 \x01(\t\x12\r\n\x05level\x18\x03 \x01(\t\"s\n!KeyphraseBoosting_UpdateKeyphrase\x12\n\n\x02id\x18\x01 \x01(\t\x12\x16\n\tkeyphrase\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05level\x18\x03 \x01(\tH\x01\x88\x01\x01\x42\x0c\n\n_keyphraseB\x08\n\x06_level\"/\n!KeyphraseBoosting_DeleteKeyphrase\x12\n\n\x02id\x18\x01 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'keyphrase_boosting_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_KEYPHRASESBOOSTING']._serialized_start=81
  _globals['_KEYPHRASESBOOSTING']._serialized_end=169
  _globals['_KEYPHRASEBOOSTING']._serialized_start=172
  _globals['_KEYPHRASEBOOSTING']._serialized_end=413
  _globals['_KEYPHRASEBOOSTING_CREATEKEYPHRASE']._serialized_start=415
  _globals['_KEYPHRASEBOOSTING_CREATEKEYPHRASE']._serialized_end=496
  _globals['_KEYPHRASEBOOSTING_UPDATEKEYPHRASE']._serialized_start=498
  _globals['_KEYPHRASEBOOSTING_UPDATEKEYPHRASE']._serialized_end=613
  _globals['_KEYPHRASEBOOSTING_DELETEKEYPHRASE']._serialized_start=615
  _globals['_KEYPHRASEBOOSTING_DELETEKEYPHRASE']._serialized_end=662
# @@protoc_insertion_point(module_scope)
