# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: languages.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0flanguages.proto\x12\tlanguages\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa0\x01\n\x08Language\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x03 \x01(\t\x12.\n\nupdated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\x05 \x01(\t\"\xc9\x01\n\tLanguages\x12\x1d\n\x15\x64\x65\x66\x61ult_language_code\x18\x01 \x01(\t\x12\x17\n\nupdated_by\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x33\n\nupdated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01\x88\x01\x01\x12\x31\n\x14\x61\x64\x64itional_languages\x18\x04 \x03(\x0b\x32\x13.languages.LanguageB\r\n\x0b_updated_byB\r\n\x0b_updated_at\"8\n\x1fLanguages_UpdateDefaultLanguage\x12\x15\n\rlanguage_code\x18\x01 \x01(\t\"%\n\x15Languages_AddLanguage\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\"(\n\x18Languages_DeleteLanguage\x12\x0c\n\x04\x63ode\x18\x01 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'languages_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_LANGUAGE']._serialized_start=64
  _globals['_LANGUAGE']._serialized_end=224
  _globals['_LANGUAGES']._serialized_start=227
  _globals['_LANGUAGES']._serialized_end=428
  _globals['_LANGUAGES_UPDATEDEFAULTLANGUAGE']._serialized_start=430
  _globals['_LANGUAGES_UPDATEDEFAULTLANGUAGE']._serialized_end=486
  _globals['_LANGUAGES_ADDLANGUAGE']._serialized_start=488
  _globals['_LANGUAGES_ADDLANGUAGE']._serialized_end=525
  _globals['_LANGUAGES_DELETELANGUAGE']._serialized_start=527
  _globals['_LANGUAGES_DELETELANGUAGE']._serialized_end=567
# @@protoc_insertion_point(module_scope)
