# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: experimental_config.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x65xperimental_config.proto\x12\x13\x65xperimental_config\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"S\n\x12\x45xperimentalConfig\x12=\n\x07\x63onfigs\x18\x01 \x03(\x0b\x32,.experimental_config.ExperimentalConfigEntry\"\xe8\x01\n\x17\x45xperimentalConfigEntry\x12\n\n\x02id\x18\x01 \x01(\t\x12)\n\x08\x66\x65\x61tures\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x04 \x01(\t\x12.\n\nupdated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\x06 \x01(\t\x12\x0e\n\x06\x61\x63tive\x18\x07 \x01(\x08\"\xb0\x01\n\x1f\x45xperimentalConfig_UpdateConfig\x12\n\n\x02id\x18\x01 \x01(\t\x12)\n\x08\x66\x65\x61tures\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x33\n\nupdated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x12\x12\n\nupdated_by\x18\x04 \x01(\tB\r\n\x0b_updated_atb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'experimental_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_EXPERIMENTALCONFIG']._serialized_start=113
  _globals['_EXPERIMENTALCONFIG']._serialized_end=196
  _globals['_EXPERIMENTALCONFIGENTRY']._serialized_start=199
  _globals['_EXPERIMENTALCONFIGENTRY']._serialized_end=431
  _globals['_EXPERIMENTALCONFIG_UPDATECONFIG']._serialized_start=434
  _globals['_EXPERIMENTALCONFIG_UPDATECONFIG']._serialized_end=610
# @@protoc_insertion_point(module_scope)
