# Copyright PolyAI Limited
# flake8: noqa
# ruff: noqa
# type: ignore
from typing import Any

__all__ = ["Memory"]


class Memory:
    """An object exposing fields in the agent memory."""

    def __init__(self, fields: dict[str, Any]) -> None: ...
    def __getitem__(self, name: str) -> Any: ...
    def get(self, name: str, default: Any = ...) -> Any | None: ...
    def __contains__(self, name: str) -> bool: ...
    def __len__(self) -> int: ...
    def fields(self) -> dict[str, Any]: ...
