# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api_integrations.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x61pi_integrations.proto\x12\x10\x61pi_integrations\x1a\x1fgoogle/protobuf/timestamp.proto\"M\n\x0f\x41piIntegrations\x12:\n\x10\x61pi_integrations\x18\x01 \x03(\x0b\x32 .api_integrations.ApiIntegration\"\xbc\x02\n\x0e\x41piIntegration\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x34\n\x0c\x65nvironments\x18\x04 \x01(\x0b\x32\x1e.api_integrations.Environments\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x06 \x01(\t\x12.\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\x08 \x01(\t\x12=\n\noperations\x18\t \x03(\x0b\x32).api_integrations.ApiIntegrationOperation\"\xba\x01\n\x0c\x45nvironments\x12\x37\n\x07sandbox\x18\x01 \x01(\x0b\x32&.api_integrations.ApiIntegrationConfig\x12;\n\x0bpre_release\x18\x02 \x01(\x0b\x32&.api_integrations.ApiIntegrationConfig\x12\x34\n\x04live\x18\x03 \x01(\x0b\x32&.api_integrations.ApiIntegrationConfig\"A\n\x14\x41piIntegrationConfig\x12\x10\n\x08\x62\x61se_url\x18\x01 \x01(\t\x12\x11\n\tauth_type\x18\x02 \x01(\tJ\x04\x08\x03\x10\x04\"\xdd\x01\n\x17\x41piIntegrationOperation\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06method\x18\x03 \x01(\t\x12\x10\n\x08resource\x18\x04 \x01(\t\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x06 \x01(\t\x12.\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\x08 \x01(\t\"\xa7\x01\n\x15\x41piIntegration_Create\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x18\n\x0b\x64\x65scription\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x39\n\x0c\x65nvironments\x18\x04 \x01(\x0b\x32\x1e.api_integrations.EnvironmentsH\x01\x88\x01\x01\x42\x0e\n\x0c_descriptionB\x0f\n\r_environments\"i\n\x15\x41piIntegration_Update\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x03 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_nameB\x0e\n\x0c_description\"#\n\x15\x41piIntegration_Delete\x12\n\n\x02id\x18\x01 \x01(\t\"\x88\x01\n\x1b\x41piIntegrationConfig_Update\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x65nvironment\x18\x02 \x01(\t\x12\x15\n\x08\x62\x61se_url\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tauth_type\x18\x04 \x01(\tH\x01\x88\x01\x01\x42\x0b\n\t_base_urlB\x0c\n\n_auth_type\"\x80\x01\n\x1e\x41piIntegrationOperation_Create\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06method\x18\x03 \x01(\t\x12\x10\n\x08resource\x18\x04 \x01(\t\x12\x16\n\x0eintegration_id\x18\x05 \x01(\t\x12\n\n\x02id\x18\x07 \x01(\tJ\x04\x08\x06\x10\x07J\x04\x08\x01\x10\x02\"\xc2\x01\n\x1e\x41piIntegrationOperation_Update\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06method\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x15\n\x08resource\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x1b\n\x0eintegration_id\x18\x05 \x01(\tH\x03\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_methodB\x0b\n\t_resourceB\x11\n\x0f_integration_idJ\x04\x08\x06\x10\x07\"J\n\x1e\x41piIntegrationOperation_Delete\x12\n\n\x02id\x18\x01 \x01(\t\x12\x16\n\x0eintegration_id\x18\x02 \x01(\tJ\x04\x08\x03\x10\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'api_integrations_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_APIINTEGRATIONS']._serialized_start=77
  _globals['_APIINTEGRATIONS']._serialized_end=154
  _globals['_APIINTEGRATION']._serialized_start=157
  _globals['_APIINTEGRATION']._serialized_end=473
  _globals['_ENVIRONMENTS']._serialized_start=476
  _globals['_ENVIRONMENTS']._serialized_end=662
  _globals['_APIINTEGRATIONCONFIG']._serialized_start=664
  _globals['_APIINTEGRATIONCONFIG']._serialized_end=729
  _globals['_APIINTEGRATIONOPERATION']._serialized_start=732
  _globals['_APIINTEGRATIONOPERATION']._serialized_end=953
  _globals['_APIINTEGRATION_CREATE']._serialized_start=956
  _globals['_APIINTEGRATION_CREATE']._serialized_end=1123
  _globals['_APIINTEGRATION_UPDATE']._serialized_start=1125
  _globals['_APIINTEGRATION_UPDATE']._serialized_end=1230
  _globals['_APIINTEGRATION_DELETE']._serialized_start=1232
  _globals['_APIINTEGRATION_DELETE']._serialized_end=1267
  _globals['_APIINTEGRATIONCONFIG_UPDATE']._serialized_start=1270
  _globals['_APIINTEGRATIONCONFIG_UPDATE']._serialized_end=1406
  _globals['_APIINTEGRATIONOPERATION_CREATE']._serialized_start=1409
  _globals['_APIINTEGRATIONOPERATION_CREATE']._serialized_end=1537
  _globals['_APIINTEGRATIONOPERATION_UPDATE']._serialized_start=1540
  _globals['_APIINTEGRATIONOPERATION_UPDATE']._serialized_end=1734
  _globals['_APIINTEGRATIONOPERATION_DELETE']._serialized_start=1736
  _globals['_APIINTEGRATIONOPERATION_DELETE']._serialized_end=1810
# @@protoc_insertion_point(module_scope)
