# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: functions.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x66unctions.proto\x12\tfunctions\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd8\x01\n\x11\x46unctionParameter\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x06 \x01(\t\x12.\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\x08 \x01(\t\">\n\rFunctionError\x12\x0e\n\x06lineno\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0c\n\x04text\x18\x03 \x01(\t\"\xa1\x01\n\x1f\x46unctionDelayResponseReferences\x12L\n\tvariables\x18\x01 \x03(\x0b\x32\x39.functions.FunctionDelayResponseReferences.VariablesEntry\x1a\x30\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"\xa2\x02\n\x15\x46unctionDelayResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x10\n\x08\x64uration\x18\x03 \x01(\x05\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x05 \x01(\t\x12.\n\nupdated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\x07 \x01(\t\x12\x43\n\nreferences\x18\x08 \x01(\x0b\x32*.functions.FunctionDelayResponseReferencesH\x00\x88\x01\x01\x42\r\n\x0b_references\"\x95\x02\n\x16\x46unctionLatencyControl\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x39\n\x0f\x64\x65lay_responses\x18\x02 \x03(\x0b\x32 .functions.FunctionDelayResponse\x12\x15\n\rinitial_delay\x18\x03 \x01(\x05\x12\x10\n\x08interval\x18\x04 \x01(\x05\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x06 \x01(\t\x12.\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\x08 \x01(\t\"\xd5\x04\n\x12\x46unctionReferences\x12@\n\nflow_steps\x18\x01 \x03(\x0b\x32,.functions.FunctionReferences.FlowStepsEntry\x12\x39\n\x06topics\x18\x02 \x03(\x0b\x32).functions.FunctionReferences.TopicsEntry\x12\x46\n\rstop_keywords\x18\x03 \x03(\x0b\x32/.functions.FunctionReferences.StopKeywordsEntry\x12?\n\tbehaviour\x18\x04 \x03(\x0b\x32,.functions.FunctionReferences.BehaviourEntry\x12?\n\tvariables\x18\x05 \x03(\x0b\x32,.functions.FunctionReferences.VariablesEntry\x1a\x30\n\x0e\x46lowStepsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a-\n\x0bTopicsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x33\n\x11StopKeywordsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x30\n\x0e\x42\x65haviourEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x30\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"\xac\x03\n\x08\x46unction\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x30\n\nparameters\x18\x04 \x03(\x0b\x32\x1c.functions.FunctionParameter\x12\x0c\n\x04\x63ode\x18\x05 \x01(\t\x12(\n\x06\x65rrors\x18\x06 \x03(\x0b\x32\x18.functions.FunctionError\x12:\n\x0flatency_control\x18\x07 \x01(\x0b\x32!.functions.FunctionLatencyControl\x12.\n\ncreated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\t \x01(\t\x12.\n\nupdated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\x0b \x01(\t\x12\x10\n\x08\x61rchived\x18\x0c \x01(\x08\x12\x31\n\nreferences\x18\r \x01(\x0b\x32\x1d.functions.FunctionReferences\"3\n\tFunctions\x12&\n\tfunctions\x18\x01 \x03(\x0b\x32\x13.functions.Function\"V\n\x17\x46unctionParameterUpdate\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\"\x93\x01\n\x1c\x46unctionCreateLatencyControl\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x39\n\x0f\x64\x65lay_responses\x18\x02 \x03(\x0b\x32 .functions.FunctionDelayResponse\x12\x15\n\rinitial_delay\x18\x03 \x01(\x05\x12\x10\n\x08interval\x18\x04 \x01(\x05\"\xfe\x02\n\x17\x46unction_CreateFunction\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x36\n\nparameters\x18\x04 \x03(\x0b\x32\".functions.FunctionParameterUpdate\x12\x0c\n\x04\x63ode\x18\x05 \x01(\t\x12(\n\x06\x65rrors\x18\x06 \x03(\x0b\x32\x18.functions.FunctionError\x12\x45\n\x0flatency_control\x18\x07 \x01(\x0b\x32\'.functions.FunctionCreateLatencyControlH\x00\x88\x01\x01\x12\x36\n\nreferences\x18\x08 \x01(\x0b\x32\x1d.functions.FunctionReferencesH\x01\x88\x01\x01\x12\x15\n\x08\x61rchived\x18\t \x01(\x08H\x02\x88\x01\x01\x42\x12\n\x10_latency_controlB\r\n\x0b_referencesB\x0b\n\t_archived\"J\n\x10ParametersUpdate\x12\x36\n\nparameters\x18\x01 \x03(\x0b\x32\".functions.FunctionParameterUpdate\"8\n\x0c\x45rrorsUpdate\x12(\n\x06\x65rrors\x18\x01 \x03(\x0b\x32\x18.functions.FunctionError\"\xf0\x02\n\x17\x46unction_UpdateFunction\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x34\n\nparameters\x18\x04 \x01(\x0b\x32\x1b.functions.ParametersUpdateH\x02\x88\x01\x01\x12\x11\n\x04\x63ode\x18\x05 \x01(\tH\x03\x88\x01\x01\x12,\n\x06\x65rrors\x18\x06 \x01(\x0b\x32\x17.functions.ErrorsUpdateH\x04\x88\x01\x01\x12\x36\n\nreferences\x18\x07 \x01(\x0b\x32\x1d.functions.FunctionReferencesH\x05\x88\x01\x01\x12\x15\n\x08\x61rchived\x18\x08 \x01(\x08H\x06\x88\x01\x01\x42\x07\n\x05_nameB\x0e\n\x0c_descriptionB\r\n\x0b_parametersB\x07\n\x05_codeB\t\n\x07_errorsB\r\n\x0b_referencesB\x0b\n\t_archived\"%\n\x17\x46unction_DeleteFunction\x12\n\n\x02id\x18\x01 \x01(\t\"\x98\x01\n\x13\x44\x65layResponseUpdate\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x10\n\x08\x64uration\x18\x03 \x01(\x05\x12\x43\n\nreferences\x18\x04 \x01(\x0b\x32*.functions.FunctionDelayResponseReferencesH\x00\x88\x01\x01\x42\r\n\x0b_references\"O\n\x14\x44\x65layResponsesUpdate\x12\x37\n\x0f\x64\x65lay_responses\x18\x01 \x03(\x0b\x32\x1e.functions.DelayResponseUpdate\"\xea\x01\n\x1d\x46unction_UpdateLatencyControl\x12\x13\n\x0b\x66unction_id\x18\x01 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12=\n\x0f\x64\x65lay_responses\x18\x03 \x01(\x0b\x32\x1f.functions.DelayResponsesUpdateH\x00\x88\x01\x01\x12\x1a\n\rinitial_delay\x18\x04 \x01(\x05H\x01\x88\x01\x01\x12\x15\n\x08interval\x18\x05 \x01(\x05H\x02\x88\x01\x01\x42\x12\n\x10_delay_responsesB\x10\n\x0e_initial_delayB\x0b\n\t_intervalb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'functions_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_FUNCTIONDELAYRESPONSEREFERENCES_VARIABLESENTRY']._options = None
  _globals['_FUNCTIONDELAYRESPONSEREFERENCES_VARIABLESENTRY']._serialized_options = b'8\001'
  _globals['_FUNCTIONREFERENCES_FLOWSTEPSENTRY']._options = None
  _globals['_FUNCTIONREFERENCES_FLOWSTEPSENTRY']._serialized_options = b'8\001'
  _globals['_FUNCTIONREFERENCES_TOPICSENTRY']._options = None
  _globals['_FUNCTIONREFERENCES_TOPICSENTRY']._serialized_options = b'8\001'
  _globals['_FUNCTIONREFERENCES_STOPKEYWORDSENTRY']._options = None
  _globals['_FUNCTIONREFERENCES_STOPKEYWORDSENTRY']._serialized_options = b'8\001'
  _globals['_FUNCTIONREFERENCES_BEHAVIOURENTRY']._options = None
  _globals['_FUNCTIONREFERENCES_BEHAVIOURENTRY']._serialized_options = b'8\001'
  _globals['_FUNCTIONREFERENCES_VARIABLESENTRY']._options = None
  _globals['_FUNCTIONREFERENCES_VARIABLESENTRY']._serialized_options = b'8\001'
  _globals['_FUNCTIONPARAMETER']._serialized_start=64
  _globals['_FUNCTIONPARAMETER']._serialized_end=280
  _globals['_FUNCTIONERROR']._serialized_start=282
  _globals['_FUNCTIONERROR']._serialized_end=344
  _globals['_FUNCTIONDELAYRESPONSEREFERENCES']._serialized_start=347
  _globals['_FUNCTIONDELAYRESPONSEREFERENCES']._serialized_end=508
  _globals['_FUNCTIONDELAYRESPONSEREFERENCES_VARIABLESENTRY']._serialized_start=460
  _globals['_FUNCTIONDELAYRESPONSEREFERENCES_VARIABLESENTRY']._serialized_end=508
  _globals['_FUNCTIONDELAYRESPONSE']._serialized_start=511
  _globals['_FUNCTIONDELAYRESPONSE']._serialized_end=801
  _globals['_FUNCTIONLATENCYCONTROL']._serialized_start=804
  _globals['_FUNCTIONLATENCYCONTROL']._serialized_end=1081
  _globals['_FUNCTIONREFERENCES']._serialized_start=1084
  _globals['_FUNCTIONREFERENCES']._serialized_end=1681
  _globals['_FUNCTIONREFERENCES_FLOWSTEPSENTRY']._serialized_start=1433
  _globals['_FUNCTIONREFERENCES_FLOWSTEPSENTRY']._serialized_end=1481
  _globals['_FUNCTIONREFERENCES_TOPICSENTRY']._serialized_start=1483
  _globals['_FUNCTIONREFERENCES_TOPICSENTRY']._serialized_end=1528
  _globals['_FUNCTIONREFERENCES_STOPKEYWORDSENTRY']._serialized_start=1530
  _globals['_FUNCTIONREFERENCES_STOPKEYWORDSENTRY']._serialized_end=1581
  _globals['_FUNCTIONREFERENCES_BEHAVIOURENTRY']._serialized_start=1583
  _globals['_FUNCTIONREFERENCES_BEHAVIOURENTRY']._serialized_end=1631
  _globals['_FUNCTIONREFERENCES_VARIABLESENTRY']._serialized_start=460
  _globals['_FUNCTIONREFERENCES_VARIABLESENTRY']._serialized_end=508
  _globals['_FUNCTION']._serialized_start=1684
  _globals['_FUNCTION']._serialized_end=2112
  _globals['_FUNCTIONS']._serialized_start=2114
  _globals['_FUNCTIONS']._serialized_end=2165
  _globals['_FUNCTIONPARAMETERUPDATE']._serialized_start=2167
  _globals['_FUNCTIONPARAMETERUPDATE']._serialized_end=2253
  _globals['_FUNCTIONCREATELATENCYCONTROL']._serialized_start=2256
  _globals['_FUNCTIONCREATELATENCYCONTROL']._serialized_end=2403
  _globals['_FUNCTION_CREATEFUNCTION']._serialized_start=2406
  _globals['_FUNCTION_CREATEFUNCTION']._serialized_end=2788
  _globals['_PARAMETERSUPDATE']._serialized_start=2790
  _globals['_PARAMETERSUPDATE']._serialized_end=2864
  _globals['_ERRORSUPDATE']._serialized_start=2866
  _globals['_ERRORSUPDATE']._serialized_end=2922
  _globals['_FUNCTION_UPDATEFUNCTION']._serialized_start=2925
  _globals['_FUNCTION_UPDATEFUNCTION']._serialized_end=3293
  _globals['_FUNCTION_DELETEFUNCTION']._serialized_start=3295
  _globals['_FUNCTION_DELETEFUNCTION']._serialized_end=3332
  _globals['_DELAYRESPONSEUPDATE']._serialized_start=3335
  _globals['_DELAYRESPONSEUPDATE']._serialized_end=3487
  _globals['_DELAYRESPONSESUPDATE']._serialized_start=3489
  _globals['_DELAYRESPONSESUPDATE']._serialized_end=3568
  _globals['_FUNCTION_UPDATELATENCYCONTROL']._serialized_start=3571
  _globals['_FUNCTION_UPDATELATENCYCONTROL']._serialized_end=3805
# @@protoc_insertion_point(module_scope)
