# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flows.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from poly.handlers.protobuf import functions_pb2 as functions__pb2
from poly.handlers.protobuf import handoff_pb2 as handoff__pb2
from poly.handlers.protobuf import sms_pb2 as sms__pb2
from poly.handlers.protobuf import variant_pb2 as variant__pb2
from poly.handlers.protobuf import entities_pb2 as entities__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x66lows.proto\x12\x05\x66lows\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x0f\x66unctions.proto\x1a\rhandoff.proto\x1a\tsms.proto\x1a\rvariant.proto\x1a\x0e\x65ntities.proto\"\x85\x03\n\x04\x46low\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x05 \x01(\t\x12.\n\nupdated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\x07 \x01(\t\x12\x15\n\rstart_step_id\x18\x08 \x01(\t\x12\x37\n\x14transition_functions\x18\n \x03(\x0b\x32\x19.flows.TransitionFunction\x12&\n\x05steps\x18\t \x03(\x0b\x32\x13.flows.AdvancedStepB\x02\x18\x01\x12-\n\rno_code_steps\x18\x0b \x03(\x0b\x32\x12.flows.DefaultStepB\x02\x18\x01\x12\x1f\n\nflow_steps\x18\x0c \x03(\x0b\x32\x0b.flows.Step\"#\n\x05\x46lows\x12\x1a\n\x05\x66lows\x18\x01 \x03(\x0b\x32\x0b.flows.Flow\"\xe9\x02\n\x0c\x41\x64vancedStep\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06prompt\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x05 \x01(\t\x12.\n\nupdated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\x07 \x01(\t\x12%\n\x08position\x18\x08 \x01(\x0b\x32\x13.flows.StepPosition\x12)\n\x0b\x61sr_biasing\x18\t \x01(\x0b\x32\x14.flows.StepAsrConfig\x12*\n\x0b\x64tmf_config\x18\n \x01(\x0b\x32\x15.flows.StepDtmfConfig\x12)\n\nreferences\x18\x0b \x01(\x0b\x32\x15.flows.StepReferences\"\xbd\x02\n\x0b\x44\x65\x66\x61ultStep\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06prompt\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x05 \x01(\t\x12.\n\nupdated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\x07 \x01(\t\x12%\n\x08position\x18\x08 \x01(\x0b\x32\x13.flows.StepPosition\x12/\n\nreferences\x18\t \x01(\x0b\x32\x1b.flows.NoCodeStepReferences\x12$\n\nconditions\x18\n \x03(\x0b\x32\x10.flows.Condition\"\xae\x02\n\x0c\x46unctionStep\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x08position\x18\x03 \x01(\x0b\x32\x13.flows.StepPosition\x12/\n\x08\x66unction\x18\x08 \x01(\x0b\x32\x1d.flows.FunctionStepDefinition\x12$\n\nconditions\x18\t \x03(\x0b\x32\x10.flows.Condition\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\x07 \x01(\t\x12\x12\n\ncreated_by\x18\x05 \x01(\t\"\x96\x01\n\x04Step\x12,\n\radvanced_step\x18\x01 \x01(\x0b\x32\x13.flows.AdvancedStepH\x00\x12*\n\x0c\x64\x65\x66\x61ult_step\x18\x02 \x01(\x0b\x32\x12.flows.DefaultStepH\x00\x12,\n\rfunction_step\x18\x03 \x01(\x0b\x32\x13.flows.FunctionStepH\x00\x42\x06\n\x04step\"\x97\x06\n\x0eStepReferences\x12+\n\x03sms\x18\x01 \x03(\x0b\x32\x1e.flows.StepReferences.SmsEntry\x12\x33\n\x07handoff\x18\x02 \x03(\x0b\x32\".flows.StepReferences.HandoffEntry\x12\x39\n\nattributes\x18\x03 \x03(\x0b\x32%.flows.StepReferences.AttributesEntry\x12L\n\x14transition_functions\x18\x04 \x03(\x0b\x32..flows.StepReferences.TransitionFunctionsEntry\x12\x44\n\x10global_functions\x18\x05 \x03(\x0b\x32*.flows.StepReferences.GlobalFunctionsEntry\x12\x35\n\x08\x65ntities\x18\x06 \x03(\x0b\x32#.flows.StepReferences.EntitiesEntry\x12\x37\n\tvariables\x18\x07 \x03(\x0b\x32$.flows.StepReferences.VariablesEntry\x1a*\n\x08SmsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a.\n\x0cHandoffEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a:\n\x18TransitionFunctionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x36\n\x14GlobalFunctionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a/\n\rEntitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x30\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"\xf3\x03\n\x14NoCodeStepReferences\x12;\n\x08\x65ntities\x18\x01 \x03(\x0b\x32).flows.NoCodeStepReferences.EntitiesEntry\x12?\n\nattributes\x18\x02 \x03(\x0b\x32+.flows.NoCodeStepReferences.AttributesEntry\x12=\n\tvariables\x18\x03 \x03(\x0b\x32*.flows.NoCodeStepReferences.VariablesEntry\x12N\n\x12\x65xtracted_entities\x18\x04 \x03(\x0b\x32\x32.flows.NoCodeStepReferences.ExtractedEntitiesEntry\x1a/\n\rEntitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x30\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x38\n\x16\x45xtractedEntitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"\x91\x02\n\x1cTransitionFunctionReferences\x12\x46\n\nflow_steps\x18\x01 \x03(\x0b\x32\x32.flows.TransitionFunctionReferences.FlowStepsEntry\x12\x45\n\tvariables\x18\x02 \x03(\x0b\x32\x32.flows.TransitionFunctionReferences.VariablesEntry\x1a\x30\n\x0e\x46lowStepsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x30\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"\xbc\x03\n\x12TransitionFunction\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x30\n\nparameters\x18\x04 \x03(\x0b\x32\x1c.functions.FunctionParameter\x12\x0c\n\x04\x63ode\x18\x05 \x01(\t\x12(\n\x06\x65rrors\x18\x06 \x03(\x0b\x32\x18.functions.FunctionError\x12:\n\x0flatency_control\x18\x07 \x01(\x0b\x32!.functions.FunctionLatencyControl\x12.\n\ncreated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\t \x01(\t\x12.\n\nupdated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\x0b \x01(\t\x12\x10\n\x08\x61rchived\x18\x0c \x01(\x08\x12\x37\n\nreferences\x18\r \x01(\x0b\x32#.flows.TransitionFunctionReferences\"\x91\x02\n\tCondition\x12\n\n\x02id\x18\x01 \x01(\t\x12\x37\n\x13\x65xit_flow_condition\x18\x02 \x01(\x0b\x32\x18.flows.ExitFlowConditionH\x00\x12\x36\n\x0estep_condition\x18\x03 \x01(\x0b\x32\x1c.flows.AdvancedStepConditionH\x00\x12<\n\x16no_code_step_condition\x18\x04 \x01(\x0b\x32\x1a.flows.NoCodeStepConditionH\x00\x12?\n\x17\x66unction_step_condition\x18\x05 \x01(\x0b\x32\x1c.flows.FunctionStepConditionH\x00\x42\x08\n\x06\x63onfig\"\xa7\x01\n\x10\x43onditionDetails\x12\r\n\x05label\x18\x01 \x01(\t\x12\x18\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x11required_entities\x18\x03 \x03(\t\x12%\n\x08position\x18\x04 \x01(\x0b\x32\x13.flows.StepPosition\x12\x18\n\x10ingress_position\x18\x05 \x01(\tB\x0e\n\x0c_description\"n\n\x11\x45xitFlowCondition\x12(\n\x07\x64\x65tails\x18\x01 \x01(\x0b\x32\x17.flows.ConditionDetails\x12/\n\x12\x65xit_flow_position\x18\x02 \x01(\x0b\x32\x13.flows.StepPosition\"X\n\x15\x41\x64vancedStepCondition\x12(\n\x07\x64\x65tails\x18\x01 \x01(\x0b\x32\x17.flows.ConditionDetails\x12\x15\n\rchild_step_id\x18\x02 \x01(\t\"V\n\x13NoCodeStepCondition\x12(\n\x07\x64\x65tails\x18\x01 \x01(\x0b\x32\x17.flows.ConditionDetails\x12\x15\n\rchild_step_id\x18\x02 \x01(\t\"X\n\x15\x46unctionStepCondition\x12(\n\x07\x64\x65tails\x18\x01 \x01(\x0b\x32\x17.flows.ConditionDetails\x12\x15\n\rchild_step_id\x18\x02 \x01(\t\"$\n\x0cStepPosition\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\"\x81\x02\n\rStepAsrConfig\x12\x14\n\x0c\x61lphanumeric\x18\x01 \x01(\x08\x12\x15\n\rname_spelling\x18\x02 \x01(\x08\x12\x0f\n\x07numeric\x18\x03 \x01(\x08\x12\x12\n\nparty_size\x18\x04 \x01(\x08\x12\x14\n\x0cprecise_date\x18\x05 \x01(\x08\x12\x15\n\rrelative_date\x18\x06 \x01(\x08\x12\x15\n\rsingle_number\x18\x07 \x01(\x08\x12\x0c\n\x04time\x18\x08 \x01(\x08\x12\x0e\n\x06yes_no\x18\t \x01(\x08\x12\x0f\n\x07\x61\x64\x64ress\x18\n \x01(\x08\x12\x17\n\x0f\x63ustom_keywords\x18\x0b \x03(\t\x12\x12\n\nis_enabled\x18\x0c \x01(\x08\"\x9c\x01\n\x0eStepDtmfConfig\x12\x12\n\nis_enabled\x18\x01 \x01(\x08\x12\x1b\n\x13inter_digit_timeout\x18\x02 \x01(\x05\x12\x12\n\nmax_digits\x18\x03 \x01(\x05\x12\x0f\n\x07\x65nd_key\x18\x04 \x01(\t\x12$\n\x1c\x63ollect_while_agent_speaking\x18\x05 \x01(\x08\x12\x0e\n\x06is_pii\x18\x06 \x01(\x08\"\x83\x02\n\x0f\x46low_CreateFlow\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x15\n\rstart_step_id\x18\x04 \x01(\t\x12(\n\x05steps\x18\x05 \x03(\x0b\x32\x19.flows.CreateAdvancedStep\x12P\n\x14transition_functions\x18\x06 \x03(\x0b\x32\x32.flows.TransitionFunction_CreateTransitionFunction\x12.\n\rno_code_steps\x18\x07 \x03(\x0b\x32\x17.flows.CreateNoCodeStep\"\xc4\x01\n\x0f\x46low_UpdateFlow\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\t\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x1a\n\rstart_step_id\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x1a\n\rold_flow_name\x18\x05 \x01(\tH\x03\x88\x01\x01\x42\x07\n\x05_nameB\x0e\n\x0c_descriptionB\x10\n\x0e_start_step_idB\x10\n\x0e_old_flow_name\"\"\n\x0f\x46low_DeleteFlow\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\t\"\xba\x03\n\x0f\x46low_ImportFlow\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\t\x12$\n\x05steps\x18\x02 \x03(\x0b\x32\x15.flows.ImportFlowStep\x12P\n\x14transition_functions\x18\x03 \x03(\x0b\x32\x32.flows.TransitionFunction_CreateTransitionFunction\x12<\n\x10global_functions\x18\x04 \x03(\x0b\x32\".functions.Function_CreateFunction\x12)\n\x08handoffs\x18\x05 \x03(\x0b\x32\x17.handoff.Handoff_Create\x12$\n\x03sms\x18\x06 \x03(\x0b\x32\x17.sms.SMS_CreateTemplate\x12\x34\n\nattributes\x18\x07 \x03(\x0b\x32 .variant.Variant_CreateAttribute\x12.\n\rno_code_steps\x18\x08 \x03(\x0b\x32\x17.flows.ImportNoCodeStep\x12)\n\x08\x65ntities\x18\t \x03(\x0b\x32\x17.entities.Entity_Create\"K\n\x0f\x46low_CreateStep\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\t\x12\'\n\x04step\x18\x02 \x01(\x0b\x32\x19.flows.CreateAdvancedStep\"K\n\x0f\x46low_UpdateStep\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\t\x12\'\n\x04step\x18\x02 \x01(\x0b\x32\x19.flows.UpdateAdvancedStep\"3\n\x0f\x46low_DeleteStep\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\t\x12\x0f\n\x07step_id\x18\x02 \x01(\t\"\x91\x02\n\x12\x43reateAdvancedStep\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06prompt\x18\x03 \x01(\t\x12%\n\x08position\x18\x04 \x01(\x0b\x32\x13.flows.StepPosition\x12)\n\nreferences\x18\x05 \x01(\x0b\x32\x15.flows.StepReferences\x12.\n\x0b\x61sr_biasing\x18\x06 \x01(\x0b\x32\x14.flows.StepAsrConfigH\x00\x88\x01\x01\x12/\n\x0b\x64tmf_config\x18\x07 \x01(\x0b\x32\x15.flows.StepDtmfConfigH\x01\x88\x01\x01\x42\x0e\n\x0c_asr_biasingB\x0e\n\x0c_dtmf_config\"\x9b\x01\n\x12UpdateAdvancedStep\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06prompt\x18\x03 \x01(\tH\x01\x88\x01\x01\x12.\n\nreferences\x18\x04 \x01(\x0b\x32\x15.flows.StepReferencesH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_promptB\r\n\x0b_references\"\xe3\x01\n\x0eImportFlowStep\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06prompt\x18\x03 \x01(\t\x12%\n\x08position\x18\x04 \x01(\x0b\x32\x13.flows.StepPosition\x12)\n\x0b\x61sr_biasing\x18\x05 \x01(\x0b\x32\x14.flows.StepAsrConfig\x12*\n\x0b\x64tmf_config\x18\x06 \x01(\x0b\x32\x15.flows.StepDtmfConfig\x12)\n\nreferences\x18\x07 \x01(\x0b\x32\x15.flows.StepReferences\"m\n\x18\x46low_UpdateStepAsrConfig\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\t\x12\x0f\n\x07step_id\x18\x02 \x01(\t\x12/\n\x0b\x61sr_biasing\x18\x03 \x01(\x0b\x32\x1a.flows.StepAsrConfigUpdate\"\x93\x04\n\x13StepAsrConfigUpdate\x12\x19\n\x0c\x61lphanumeric\x18\x03 \x01(\x08H\x00\x88\x01\x01\x12\x1a\n\rname_spelling\x18\x04 \x01(\x08H\x01\x88\x01\x01\x12\x14\n\x07numeric\x18\x05 \x01(\x08H\x02\x88\x01\x01\x12\x17\n\nparty_size\x18\x06 \x01(\x08H\x03\x88\x01\x01\x12\x19\n\x0cprecise_date\x18\x07 \x01(\x08H\x04\x88\x01\x01\x12\x1a\n\rrelative_date\x18\x08 \x01(\x08H\x05\x88\x01\x01\x12\x1a\n\rsingle_number\x18\t \x01(\x08H\x06\x88\x01\x01\x12\x11\n\x04time\x18\n \x01(\x08H\x07\x88\x01\x01\x12\x13\n\x06yes_no\x18\x0b \x01(\x08H\x08\x88\x01\x01\x12\x14\n\x07\x61\x64\x64ress\x18\x0c \x01(\x08H\t\x88\x01\x01\x12\x36\n\x0f\x63ustom_keywords\x18\r \x01(\x0b\x32\x18.flows.UpdateAsrKeywordsH\n\x88\x01\x01\x12\x17\n\nis_enabled\x18\x0e \x01(\x08H\x0b\x88\x01\x01\x42\x0f\n\r_alphanumericB\x10\n\x0e_name_spellingB\n\n\x08_numericB\r\n\x0b_party_sizeB\x0f\n\r_precise_dateB\x10\n\x0e_relative_dateB\x10\n\x0e_single_numberB\x07\n\x05_timeB\t\n\x07_yes_noB\n\n\x08_addressB\x12\n\x10_custom_keywordsB\r\n\x0b_is_enabled\",\n\x11UpdateAsrKeywords\x12\x17\n\x0f\x63ustom_keywords\x18\x01 \x03(\t\"o\n\x19\x46low_UpdateStepDtmfConfig\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\t\x12\x0f\n\x07step_id\x18\x02 \x01(\t\x12\x30\n\x0b\x64tmf_config\x18\x03 \x01(\x0b\x32\x1b.flows.StepDtmfConfigUpdate\"\xae\x02\n\x14StepDtmfConfigUpdate\x12\x17\n\nis_enabled\x18\x03 \x01(\x08H\x00\x88\x01\x01\x12 \n\x13inter_digit_timeout\x18\x04 \x01(\x05H\x01\x88\x01\x01\x12\x17\n\nmax_digits\x18\x05 \x01(\x05H\x02\x88\x01\x01\x12\x14\n\x07\x65nd_key\x18\x06 \x01(\tH\x03\x88\x01\x01\x12)\n\x1c\x63ollect_while_agent_speaking\x18\x07 \x01(\x08H\x04\x88\x01\x01\x12\x13\n\x06is_pii\x18\x08 \x01(\x08H\x05\x88\x01\x01\x42\r\n\x0b_is_enabledB\x16\n\x14_inter_digit_timeoutB\r\n\x0b_max_digitsB\n\n\x08_end_keyB\x1f\n\x1d_collect_while_agent_speakingB\t\n\x07_is_pii\"^\n\x17\x46low_UpdateStepPosition\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\t\x12\x32\n\x0fposition_update\x18\x02 \x01(\x0b\x32\x19.flows.StepPositionUpdate\"]\n\x18\x46low_UpdateStepPositions\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\t\x12\x30\n\rnew_positions\x18\x02 \x03(\x0b\x32\x19.flows.StepPositionUpdate\"P\n\x12StepPositionUpdate\x12\x0f\n\x07step_id\x18\x01 \x01(\t\x12)\n\x0cnew_position\x18\x02 \x01(\x0b\x32\x13.flows.StepPosition\"X\n\x11MoveFlowComponent\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\t\x12\x32\n\x0fposition_detail\x18\x02 \x01(\x0b\x32\x19.flows.FlowPositionDetail\"Z\n\x12MoveFlowComponents\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\t\x12\x33\n\x10position_details\x18\x02 \x03(\x0b\x32\x19.flows.FlowPositionDetail\"\x90\x04\n\x12\x46lowPositionDetail\x12\x33\n\tflow_step\x18\x01 \x01(\x0b\x32\x1e.flows.FlowStepPositionDetailsH\x00\x12\x37\n\x0cno_code_step\x18\x02 \x01(\x0b\x32\x1f.flows.NoCodeStepPositionDetailH\x00\x12J\n\x16no_code_step_condition\x18\x03 \x01(\x0b\x32(.flows.NoCodeStepConditionPositionDetailH\x00\x12S\n no_code_step_condition_exit_flow\x18\x04 \x01(\x0b\x32\'.flows.NoCodeStepExitFlowPositionDetailH\x00\x12:\n\rfunction_step\x18\x05 \x01(\x0b\x32!.flows.FunctionStepPositionDetailH\x00\x12M\n\x17\x66unction_step_condition\x18\x06 \x01(\x0b\x32*.flows.FunctionStepConditionPositionDetailH\x00\x12V\n!function_step_condition_exit_flow\x18\x07 \x01(\x0b\x32).flows.FunctionStepExitFlowPositionDetailH\x00\x42\x08\n\x06\x64\x65tail\"U\n\x17\x46lowStepPositionDetails\x12\x0f\n\x07step_id\x18\x01 \x01(\t\x12)\n\x0cnew_position\x18\x02 \x01(\x0b\x32\x13.flows.StepPosition\"V\n\x18NoCodeStepPositionDetail\x12\x0f\n\x07step_id\x18\x01 \x01(\t\x12)\n\x0cnew_position\x18\x02 \x01(\x0b\x32\x13.flows.StepPosition\"u\n!NoCodeStepConditionPositionDetail\x12\x0f\n\x07step_id\x18\x01 \x01(\t\x12\x14\n\x0c\x63ondition_id\x18\x02 \x01(\t\x12)\n\x0cnew_position\x18\x03 \x01(\x0b\x32\x13.flows.StepPosition\"t\n NoCodeStepExitFlowPositionDetail\x12\x0f\n\x07step_id\x18\x01 \x01(\t\x12\x14\n\x0c\x63ondition_id\x18\x02 \x01(\t\x12)\n\x0cnew_position\x18\x03 \x01(\x0b\x32\x13.flows.StepPosition\"X\n\x1a\x46unctionStepPositionDetail\x12\x0f\n\x07step_id\x18\x01 \x01(\t\x12)\n\x0cnew_position\x18\x02 \x01(\x0b\x32\x13.flows.StepPosition\"w\n#FunctionStepConditionPositionDetail\x12\x0f\n\x07step_id\x18\x01 \x01(\t\x12\x14\n\x0c\x63ondition_id\x18\x02 \x01(\t\x12)\n\x0cnew_position\x18\x03 \x01(\x0b\x32\x13.flows.StepPosition\"v\n\"FunctionStepExitFlowPositionDetail\x12\x0f\n\x07step_id\x18\x01 \x01(\t\x12\x14\n\x0c\x63ondition_id\x18\x02 \x01(\t\x12)\n\x0cnew_position\x18\x03 \x01(\x0b\x32\x13.flows.StepPosition\"\x81\x01\n\x1d\x46low_CreateTransitionFunction\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\t\x12O\n\x13transition_function\x18\x02 \x01(\x0b\x32\x32.flows.TransitionFunction_CreateTransitionFunction\"\x81\x01\n\x1d\x46low_UpdateTransitionFunction\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\t\x12O\n\x13transition_function\x18\x02 \x01(\x0b\x32\x32.flows.TransitionFunction_UpdateTransitionFunction\"\x81\x01\n+Flow_UpdateTransitionFunctionLatencyControl\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\t\x12\x41\n\x0flatency_control\x18\x02 \x01(\x0b\x32(.functions.Function_UpdateLatencyControl\"E\n\x1d\x46low_DeleteTransitionFunction\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\t\x12\x13\n\x0b\x66unction_id\x18\x02 \x01(\t\"\x98\x03\n+TransitionFunction_CreateTransitionFunction\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x36\n\nparameters\x18\x04 \x03(\x0b\x32\".functions.FunctionParameterUpdate\x12\x0c\n\x04\x63ode\x18\x05 \x01(\t\x12(\n\x06\x65rrors\x18\x06 \x03(\x0b\x32\x18.functions.FunctionError\x12\x45\n\x0flatency_control\x18\x07 \x01(\x0b\x32\'.functions.FunctionCreateLatencyControlH\x00\x88\x01\x01\x12<\n\nreferences\x18\x08 \x01(\x0b\x32#.flows.TransitionFunctionReferencesH\x01\x88\x01\x01\x12\x15\n\x08\x61rchived\x18\t \x01(\x08H\x02\x88\x01\x01\x42\x12\n\x10_latency_controlB\r\n\x0b_referencesB\x0b\n\t_archived\"\x99\x02\n+TransitionFunction_UpdateTransitionFunction\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x34\n\nparameters\x18\x04 \x01(\x0b\x32\x1b.functions.ParametersUpdateH\x02\x88\x01\x01\x12\x11\n\x04\x63ode\x18\x05 \x01(\tH\x03\x88\x01\x01\x12,\n\x06\x65rrors\x18\x06 \x01(\x0b\x32\x17.functions.ErrorsUpdateH\x04\x88\x01\x01\x42\x07\n\x05_nameB\x0e\n\x0c_descriptionB\r\n\x0b_parametersB\x07\n\x05_codeB\t\n\x07_errors\"\xaa\x01\n\x10\x43reateNoCodeStep\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\t\x12\x0f\n\x07step_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0e\n\x06prompt\x18\x04 \x01(\t\x12%\n\x08position\x18\x05 \x01(\x0b\x32\x13.flows.StepPosition\x12/\n\nreferences\x18\x06 \x01(\x0b\x32\x1b.flows.NoCodeStepReferences\"\xee\x01\n\x10UpdateNoCodeStep\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\t\x12\x0f\n\x07step_id\x18\x02 \x01(\t\x12\x11\n\x04name\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06prompt\x18\x04 \x01(\tH\x01\x88\x01\x01\x12*\n\x08position\x18\x05 \x01(\x0b\x32\x13.flows.StepPositionH\x02\x88\x01\x01\x12\x34\n\nreferences\x18\x06 \x01(\x0b\x32\x1b.flows.NoCodeStepReferencesH\x03\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_promptB\x0b\n\t_positionB\r\n\x0b_references\"4\n\x10\x44\x65leteNoCodeStep\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\t\x12\x0f\n\x07step_id\x18\x02 \x01(\t\"g\n\x18UpdateNoCodeStepPosition\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\t\x12\x0f\n\x07step_id\x18\x02 \x01(\t\x12)\n\x0cnew_position\x18\x03 \x01(\x0b\x32\x13.flows.StepPosition\"\xba\x01\n\x10ImportNoCodeStep\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06prompt\x18\x03 \x01(\t\x12%\n\x08position\x18\x04 \x01(\x0b\x32\x13.flows.StepPosition\x12/\n\nreferences\x18\x05 \x01(\x0b\x32\x1b.flows.NoCodeStepReferences\x12$\n\nconditions\x18\x06 \x03(\x0b\x32\x10.flows.Condition\"\xc9\x02\n\x15\x43reateNoCodeCondition\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\t\x12\x0f\n\x07step_id\x18\x02 \x01(\t\x12\x14\n\x0c\x63ondition_id\x18\x03 \x01(\t\x12\x37\n\x13\x65xit_flow_condition\x18\x04 \x01(\x0b\x32\x18.flows.ExitFlowConditionH\x00\x12\x36\n\x0estep_condition\x18\x05 \x01(\x0b\x32\x1c.flows.AdvancedStepConditionH\x00\x12<\n\x16no_code_step_condition\x18\x06 \x01(\x0b\x32\x1a.flows.NoCodeStepConditionH\x00\x12?\n\x17\x66unction_step_condition\x18\x07 \x01(\x0b\x32\x1c.flows.FunctionStepConditionH\x00\x42\x08\n\x06\x63onfig\"\xc9\x02\n\x15UpdateNoCodeCondition\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\t\x12\x0f\n\x07step_id\x18\x02 \x01(\t\x12\x14\n\x0c\x63ondition_id\x18\x03 \x01(\t\x12\x37\n\x13\x65xit_flow_condition\x18\x04 \x01(\x0b\x32\x18.flows.ExitFlowConditionH\x00\x12\x36\n\x0estep_condition\x18\x05 \x01(\x0b\x32\x1c.flows.AdvancedStepConditionH\x00\x12<\n\x16no_code_step_condition\x18\x06 \x01(\x0b\x32\x1a.flows.NoCodeStepConditionH\x00\x12?\n\x17\x66unction_step_condition\x18\x07 \x01(\x0b\x32\x1c.flows.FunctionStepConditionH\x00\x42\x08\n\x06\x63onfig\"O\n\x15\x44\x65leteNoCodeCondition\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\t\x12\x0f\n\x07step_id\x18\x02 \x01(\t\x12\x14\n\x0c\x63ondition_id\x18\x03 \x01(\t\"\x82\x01\n\x1dUpdateNoCodeConditionPosition\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\t\x12\x0f\n\x07step_id\x18\x02 \x01(\t\x12\x14\n\x0c\x63ondition_id\x18\x03 \x01(\t\x12)\n\x0cnew_position\x18\x04 \x01(\x0b\x32\x13.flows.StepPosition\"\x8a\x01\n%UpdateNoCodeConditionExitFlowPosition\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\t\x12\x0f\n\x07step_id\x18\x02 \x01(\t\x12\x14\n\x0c\x63ondition_id\x18\x03 \x01(\t\x12)\n\x0cnew_position\x18\x04 \x01(\x0b\x32\x13.flows.StepPosition\"\\\n\nCreateStep\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\t\x12\x32\n\rfunction_step\x18\x02 \x01(\x0b\x32\x19.flows.CreateFunctionStepH\x00\x42\t\n\x07payload\"m\n\nUpdateStep\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\t\x12\x0f\n\x07step_id\x18\x02 \x01(\t\x12\x32\n\rfunction_step\x18\x03 \x01(\x0b\x32\x19.flows.UpdateFunctionStepH\x00\x42\t\n\x07payload\".\n\nDeleteStep\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\t\x12\x0f\n\x07step_id\x18\x02 \x01(\t\"\xc7\x02\n\x13\x43reateStepCondition\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\t\x12\x0f\n\x07step_id\x18\x02 \x01(\t\x12\x14\n\x0c\x63ondition_id\x18\x03 \x01(\t\x12\x37\n\x13\x65xit_flow_condition\x18\x04 \x01(\x0b\x32\x18.flows.ExitFlowConditionH\x00\x12\x36\n\x0estep_condition\x18\x05 \x01(\x0b\x32\x1c.flows.AdvancedStepConditionH\x00\x12<\n\x16no_code_step_condition\x18\x06 \x01(\x0b\x32\x1a.flows.NoCodeStepConditionH\x00\x12?\n\x17\x66unction_step_condition\x18\x07 \x01(\x0b\x32\x1c.flows.FunctionStepConditionH\x00\x42\x08\n\x06\x63onfig\"\xc7\x02\n\x13UpdateStepCondition\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\t\x12\x0f\n\x07step_id\x18\x02 \x01(\t\x12\x14\n\x0c\x63ondition_id\x18\x03 \x01(\t\x12\x37\n\x13\x65xit_flow_condition\x18\x04 \x01(\x0b\x32\x18.flows.ExitFlowConditionH\x00\x12\x36\n\x0estep_condition\x18\x05 \x01(\x0b\x32\x1c.flows.AdvancedStepConditionH\x00\x12<\n\x16no_code_step_condition\x18\x06 \x01(\x0b\x32\x1a.flows.NoCodeStepConditionH\x00\x12?\n\x17\x66unction_step_condition\x18\x07 \x01(\x0b\x32\x1c.flows.FunctionStepConditionH\x00\x42\x08\n\x06\x63onfig\"M\n\x13\x44\x65leteStepCondition\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\t\x12\x0f\n\x07step_id\x18\x02 \x01(\t\x12\x14\n\x0c\x63ondition_id\x18\x03 \x01(\t\"\x80\x01\n\x1bUpdateStepConditionPosition\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\t\x12\x0f\n\x07step_id\x18\x02 \x01(\t\x12\x14\n\x0c\x63ondition_id\x18\x03 \x01(\t\x12)\n\x0cnew_position\x18\x04 \x01(\x0b\x32\x13.flows.StepPosition\"\xc0\x02\n\x16\x46unctionStepDefinition\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12(\n\x06\x65rrors\x18\x04 \x03(\x0b\x32\x18.functions.FunctionError\x12:\n\x0flatency_control\x18\x05 \x01(\x0b\x32!.functions.FunctionLatencyControl\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x07 \x01(\t\x12.\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\t \x01(\t\x12\x10\n\x08\x61rchived\x18\n \x01(\x08\"\x8c\x01\n\x12\x43reateFunctionStep\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12%\n\x08position\x18\x05 \x01(\x0b\x32\x13.flows.StepPosition\x12\x35\n\x08\x66unction\x18\x06 \x01(\x0b\x32#.flows.CreateFunctionStepDefinition\"\xb2\x01\n\x12UpdateFunctionStep\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12*\n\x08position\x18\x02 \x01(\x0b\x32\x13.flows.StepPositionH\x01\x88\x01\x01\x12:\n\x08\x66unction\x18\x03 \x01(\x0b\x32#.flows.UpdateFunctionStepDefinitionH\x02\x88\x01\x01\x42\x07\n\x05_nameB\x0b\n\t_positionB\x0b\n\t_function\"\xcb\x01\n\x1c\x43reateFunctionStepDefinition\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12(\n\x06\x65rrors\x18\x04 \x03(\x0b\x32\x18.functions.FunctionError\x12\x45\n\x0flatency_control\x18\x05 \x01(\x0b\x32\'.functions.FunctionCreateLatencyControlH\x00\x88\x01\x01\x42\x12\n\x10_latency_control\"\x9c\x02\n\x1cUpdateFunctionStepDefinition\x12\x18\n\x0b\x64\x65scription\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04\x63ode\x18\x05 \x01(\tH\x01\x88\x01\x01\x12,\n\x06\x65rrors\x18\x06 \x01(\x0b\x32\x17.functions.ErrorsUpdateH\x02\x88\x01\x01\x12\x15\n\x08\x61rchived\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x45\n\x0flatency_control\x18\x07 \x01(\x0b\x32\'.functions.FunctionCreateLatencyControlH\x04\x88\x01\x01\x42\x0e\n\x0c_descriptionB\x07\n\x05_codeB\t\n\x07_errorsB\x0b\n\t_archivedB\x12\n\x10_latency_controlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'flows_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_FLOW'].fields_by_name['steps']._options = None
  _globals['_FLOW'].fields_by_name['steps']._serialized_options = b'\030\001'
  _globals['_FLOW'].fields_by_name['no_code_steps']._options = None
  _globals['_FLOW'].fields_by_name['no_code_steps']._serialized_options = b'\030\001'
  _globals['_STEPREFERENCES_SMSENTRY']._options = None
  _globals['_STEPREFERENCES_SMSENTRY']._serialized_options = b'8\001'
  _globals['_STEPREFERENCES_HANDOFFENTRY']._options = None
  _globals['_STEPREFERENCES_HANDOFFENTRY']._serialized_options = b'8\001'
  _globals['_STEPREFERENCES_ATTRIBUTESENTRY']._options = None
  _globals['_STEPREFERENCES_ATTRIBUTESENTRY']._serialized_options = b'8\001'
  _globals['_STEPREFERENCES_TRANSITIONFUNCTIONSENTRY']._options = None
  _globals['_STEPREFERENCES_TRANSITIONFUNCTIONSENTRY']._serialized_options = b'8\001'
  _globals['_STEPREFERENCES_GLOBALFUNCTIONSENTRY']._options = None
  _globals['_STEPREFERENCES_GLOBALFUNCTIONSENTRY']._serialized_options = b'8\001'
  _globals['_STEPREFERENCES_ENTITIESENTRY']._options = None
  _globals['_STEPREFERENCES_ENTITIESENTRY']._serialized_options = b'8\001'
  _globals['_STEPREFERENCES_VARIABLESENTRY']._options = None
  _globals['_STEPREFERENCES_VARIABLESENTRY']._serialized_options = b'8\001'
  _globals['_NOCODESTEPREFERENCES_ENTITIESENTRY']._options = None
  _globals['_NOCODESTEPREFERENCES_ENTITIESENTRY']._serialized_options = b'8\001'
  _globals['_NOCODESTEPREFERENCES_ATTRIBUTESENTRY']._options = None
  _globals['_NOCODESTEPREFERENCES_ATTRIBUTESENTRY']._serialized_options = b'8\001'
  _globals['_NOCODESTEPREFERENCES_VARIABLESENTRY']._options = None
  _globals['_NOCODESTEPREFERENCES_VARIABLESENTRY']._serialized_options = b'8\001'
  _globals['_NOCODESTEPREFERENCES_EXTRACTEDENTITIESENTRY']._options = None
  _globals['_NOCODESTEPREFERENCES_EXTRACTEDENTITIESENTRY']._serialized_options = b'8\001'
  _globals['_TRANSITIONFUNCTIONREFERENCES_FLOWSTEPSENTRY']._options = None
  _globals['_TRANSITIONFUNCTIONREFERENCES_FLOWSTEPSENTRY']._serialized_options = b'8\001'
  _globals['_TRANSITIONFUNCTIONREFERENCES_VARIABLESENTRY']._options = None
  _globals['_TRANSITIONFUNCTIONREFERENCES_VARIABLESENTRY']._serialized_options = b'8\001'
  _globals['_FLOW']._serialized_start=130
  _globals['_FLOW']._serialized_end=519
  _globals['_FLOWS']._serialized_start=521
  _globals['_FLOWS']._serialized_end=556
  _globals['_ADVANCEDSTEP']._serialized_start=559
  _globals['_ADVANCEDSTEP']._serialized_end=920
  _globals['_DEFAULTSTEP']._serialized_start=923
  _globals['_DEFAULTSTEP']._serialized_end=1240
  _globals['_FUNCTIONSTEP']._serialized_start=1243
  _globals['_FUNCTIONSTEP']._serialized_end=1545
  _globals['_STEP']._serialized_start=1548
  _globals['_STEP']._serialized_end=1698
  _globals['_STEPREFERENCES']._serialized_start=1701
  _globals['_STEPREFERENCES']._serialized_end=2492
  _globals['_STEPREFERENCES_SMSENTRY']._serialized_start=2136
  _globals['_STEPREFERENCES_SMSENTRY']._serialized_end=2178
  _globals['_STEPREFERENCES_HANDOFFENTRY']._serialized_start=2180
  _globals['_STEPREFERENCES_HANDOFFENTRY']._serialized_end=2226
  _globals['_STEPREFERENCES_ATTRIBUTESENTRY']._serialized_start=2228
  _globals['_STEPREFERENCES_ATTRIBUTESENTRY']._serialized_end=2277
  _globals['_STEPREFERENCES_TRANSITIONFUNCTIONSENTRY']._serialized_start=2279
  _globals['_STEPREFERENCES_TRANSITIONFUNCTIONSENTRY']._serialized_end=2337
  _globals['_STEPREFERENCES_GLOBALFUNCTIONSENTRY']._serialized_start=2339
  _globals['_STEPREFERENCES_GLOBALFUNCTIONSENTRY']._serialized_end=2393
  _globals['_STEPREFERENCES_ENTITIESENTRY']._serialized_start=2395
  _globals['_STEPREFERENCES_ENTITIESENTRY']._serialized_end=2442
  _globals['_STEPREFERENCES_VARIABLESENTRY']._serialized_start=2444
  _globals['_STEPREFERENCES_VARIABLESENTRY']._serialized_end=2492
  _globals['_NOCODESTEPREFERENCES']._serialized_start=2495
  _globals['_NOCODESTEPREFERENCES']._serialized_end=2994
  _globals['_NOCODESTEPREFERENCES_ENTITIESENTRY']._serialized_start=2395
  _globals['_NOCODESTEPREFERENCES_ENTITIESENTRY']._serialized_end=2442
  _globals['_NOCODESTEPREFERENCES_ATTRIBUTESENTRY']._serialized_start=2228
  _globals['_NOCODESTEPREFERENCES_ATTRIBUTESENTRY']._serialized_end=2277
  _globals['_NOCODESTEPREFERENCES_VARIABLESENTRY']._serialized_start=2444
  _globals['_NOCODESTEPREFERENCES_VARIABLESENTRY']._serialized_end=2492
  _globals['_NOCODESTEPREFERENCES_EXTRACTEDENTITIESENTRY']._serialized_start=2938
  _globals['_NOCODESTEPREFERENCES_EXTRACTEDENTITIESENTRY']._serialized_end=2994
  _globals['_TRANSITIONFUNCTIONREFERENCES']._serialized_start=2997
  _globals['_TRANSITIONFUNCTIONREFERENCES']._serialized_end=3270
  _globals['_TRANSITIONFUNCTIONREFERENCES_FLOWSTEPSENTRY']._serialized_start=3172
  _globals['_TRANSITIONFUNCTIONREFERENCES_FLOWSTEPSENTRY']._serialized_end=3220
  _globals['_TRANSITIONFUNCTIONREFERENCES_VARIABLESENTRY']._serialized_start=2444
  _globals['_TRANSITIONFUNCTIONREFERENCES_VARIABLESENTRY']._serialized_end=2492
  _globals['_TRANSITIONFUNCTION']._serialized_start=3273
  _globals['_TRANSITIONFUNCTION']._serialized_end=3717
  _globals['_CONDITION']._serialized_start=3720
  _globals['_CONDITION']._serialized_end=3993
  _globals['_CONDITIONDETAILS']._serialized_start=3996
  _globals['_CONDITIONDETAILS']._serialized_end=4163
  _globals['_EXITFLOWCONDITION']._serialized_start=4165
  _globals['_EXITFLOWCONDITION']._serialized_end=4275
  _globals['_ADVANCEDSTEPCONDITION']._serialized_start=4277
  _globals['_ADVANCEDSTEPCONDITION']._serialized_end=4365
  _globals['_NOCODESTEPCONDITION']._serialized_start=4367
  _globals['_NOCODESTEPCONDITION']._serialized_end=4453
  _globals['_FUNCTIONSTEPCONDITION']._serialized_start=4455
  _globals['_FUNCTIONSTEPCONDITION']._serialized_end=4543
  _globals['_STEPPOSITION']._serialized_start=4545
  _globals['_STEPPOSITION']._serialized_end=4581
  _globals['_STEPASRCONFIG']._serialized_start=4584
  _globals['_STEPASRCONFIG']._serialized_end=4841
  _globals['_STEPDTMFCONFIG']._serialized_start=4844
  _globals['_STEPDTMFCONFIG']._serialized_end=5000
  _globals['_FLOW_CREATEFLOW']._serialized_start=5003
  _globals['_FLOW_CREATEFLOW']._serialized_end=5262
  _globals['_FLOW_UPDATEFLOW']._serialized_start=5265
  _globals['_FLOW_UPDATEFLOW']._serialized_end=5461
  _globals['_FLOW_DELETEFLOW']._serialized_start=5463
  _globals['_FLOW_DELETEFLOW']._serialized_end=5497
  _globals['_FLOW_IMPORTFLOW']._serialized_start=5500
  _globals['_FLOW_IMPORTFLOW']._serialized_end=5942
  _globals['_FLOW_CREATESTEP']._serialized_start=5944
  _globals['_FLOW_CREATESTEP']._serialized_end=6019
  _globals['_FLOW_UPDATESTEP']._serialized_start=6021
  _globals['_FLOW_UPDATESTEP']._serialized_end=6096
  _globals['_FLOW_DELETESTEP']._serialized_start=6098
  _globals['_FLOW_DELETESTEP']._serialized_end=6149
  _globals['_CREATEADVANCEDSTEP']._serialized_start=6152
  _globals['_CREATEADVANCEDSTEP']._serialized_end=6425
  _globals['_UPDATEADVANCEDSTEP']._serialized_start=6428
  _globals['_UPDATEADVANCEDSTEP']._serialized_end=6583
  _globals['_IMPORTFLOWSTEP']._serialized_start=6586
  _globals['_IMPORTFLOWSTEP']._serialized_end=6813
  _globals['_FLOW_UPDATESTEPASRCONFIG']._serialized_start=6815
  _globals['_FLOW_UPDATESTEPASRCONFIG']._serialized_end=6924
  _globals['_STEPASRCONFIGUPDATE']._serialized_start=6927
  _globals['_STEPASRCONFIGUPDATE']._serialized_end=7458
  _globals['_UPDATEASRKEYWORDS']._serialized_start=7460
  _globals['_UPDATEASRKEYWORDS']._serialized_end=7504
  _globals['_FLOW_UPDATESTEPDTMFCONFIG']._serialized_start=7506
  _globals['_FLOW_UPDATESTEPDTMFCONFIG']._serialized_end=7617
  _globals['_STEPDTMFCONFIGUPDATE']._serialized_start=7620
  _globals['_STEPDTMFCONFIGUPDATE']._serialized_end=7922
  _globals['_FLOW_UPDATESTEPPOSITION']._serialized_start=7924
  _globals['_FLOW_UPDATESTEPPOSITION']._serialized_end=8018
  _globals['_FLOW_UPDATESTEPPOSITIONS']._serialized_start=8020
  _globals['_FLOW_UPDATESTEPPOSITIONS']._serialized_end=8113
  _globals['_STEPPOSITIONUPDATE']._serialized_start=8115
  _globals['_STEPPOSITIONUPDATE']._serialized_end=8195
  _globals['_MOVEFLOWCOMPONENT']._serialized_start=8197
  _globals['_MOVEFLOWCOMPONENT']._serialized_end=8285
  _globals['_MOVEFLOWCOMPONENTS']._serialized_start=8287
  _globals['_MOVEFLOWCOMPONENTS']._serialized_end=8377
  _globals['_FLOWPOSITIONDETAIL']._serialized_start=8380
  _globals['_FLOWPOSITIONDETAIL']._serialized_end=8908
  _globals['_FLOWSTEPPOSITIONDETAILS']._serialized_start=8910
  _globals['_FLOWSTEPPOSITIONDETAILS']._serialized_end=8995
  _globals['_NOCODESTEPPOSITIONDETAIL']._serialized_start=8997
  _globals['_NOCODESTEPPOSITIONDETAIL']._serialized_end=9083
  _globals['_NOCODESTEPCONDITIONPOSITIONDETAIL']._serialized_start=9085
  _globals['_NOCODESTEPCONDITIONPOSITIONDETAIL']._serialized_end=9202
  _globals['_NOCODESTEPEXITFLOWPOSITIONDETAIL']._serialized_start=9204
  _globals['_NOCODESTEPEXITFLOWPOSITIONDETAIL']._serialized_end=9320
  _globals['_FUNCTIONSTEPPOSITIONDETAIL']._serialized_start=9322
  _globals['_FUNCTIONSTEPPOSITIONDETAIL']._serialized_end=9410
  _globals['_FUNCTIONSTEPCONDITIONPOSITIONDETAIL']._serialized_start=9412
  _globals['_FUNCTIONSTEPCONDITIONPOSITIONDETAIL']._serialized_end=9531
  _globals['_FUNCTIONSTEPEXITFLOWPOSITIONDETAIL']._serialized_start=9533
  _globals['_FUNCTIONSTEPEXITFLOWPOSITIONDETAIL']._serialized_end=9651
  _globals['_FLOW_CREATETRANSITIONFUNCTION']._serialized_start=9654
  _globals['_FLOW_CREATETRANSITIONFUNCTION']._serialized_end=9783
  _globals['_FLOW_UPDATETRANSITIONFUNCTION']._serialized_start=9786
  _globals['_FLOW_UPDATETRANSITIONFUNCTION']._serialized_end=9915
  _globals['_FLOW_UPDATETRANSITIONFUNCTIONLATENCYCONTROL']._serialized_start=9918
  _globals['_FLOW_UPDATETRANSITIONFUNCTIONLATENCYCONTROL']._serialized_end=10047
  _globals['_FLOW_DELETETRANSITIONFUNCTION']._serialized_start=10049
  _globals['_FLOW_DELETETRANSITIONFUNCTION']._serialized_end=10118
  _globals['_TRANSITIONFUNCTION_CREATETRANSITIONFUNCTION']._serialized_start=10121
  _globals['_TRANSITIONFUNCTION_CREATETRANSITIONFUNCTION']._serialized_end=10529
  _globals['_TRANSITIONFUNCTION_UPDATETRANSITIONFUNCTION']._serialized_start=10532
  _globals['_TRANSITIONFUNCTION_UPDATETRANSITIONFUNCTION']._serialized_end=10813
  _globals['_CREATENOCODESTEP']._serialized_start=10816
  _globals['_CREATENOCODESTEP']._serialized_end=10986
  _globals['_UPDATENOCODESTEP']._serialized_start=10989
  _globals['_UPDATENOCODESTEP']._serialized_end=11227
  _globals['_DELETENOCODESTEP']._serialized_start=11229
  _globals['_DELETENOCODESTEP']._serialized_end=11281
  _globals['_UPDATENOCODESTEPPOSITION']._serialized_start=11283
  _globals['_UPDATENOCODESTEPPOSITION']._serialized_end=11386
  _globals['_IMPORTNOCODESTEP']._serialized_start=11389
  _globals['_IMPORTNOCODESTEP']._serialized_end=11575
  _globals['_CREATENOCODECONDITION']._serialized_start=11578
  _globals['_CREATENOCODECONDITION']._serialized_end=11907
  _globals['_UPDATENOCODECONDITION']._serialized_start=11910
  _globals['_UPDATENOCODECONDITION']._serialized_end=12239
  _globals['_DELETENOCODECONDITION']._serialized_start=12241
  _globals['_DELETENOCODECONDITION']._serialized_end=12320
  _globals['_UPDATENOCODECONDITIONPOSITION']._serialized_start=12323
  _globals['_UPDATENOCODECONDITIONPOSITION']._serialized_end=12453
  _globals['_UPDATENOCODECONDITIONEXITFLOWPOSITION']._serialized_start=12456
  _globals['_UPDATENOCODECONDITIONEXITFLOWPOSITION']._serialized_end=12594
  _globals['_CREATESTEP']._serialized_start=12596
  _globals['_CREATESTEP']._serialized_end=12688
  _globals['_UPDATESTEP']._serialized_start=12690
  _globals['_UPDATESTEP']._serialized_end=12799
  _globals['_DELETESTEP']._serialized_start=12801
  _globals['_DELETESTEP']._serialized_end=12847
  _globals['_CREATESTEPCONDITION']._serialized_start=12850
  _globals['_CREATESTEPCONDITION']._serialized_end=13177
  _globals['_UPDATESTEPCONDITION']._serialized_start=13180
  _globals['_UPDATESTEPCONDITION']._serialized_end=13507
  _globals['_DELETESTEPCONDITION']._serialized_start=13509
  _globals['_DELETESTEPCONDITION']._serialized_end=13586
  _globals['_UPDATESTEPCONDITIONPOSITION']._serialized_start=13589
  _globals['_UPDATESTEPCONDITIONPOSITION']._serialized_end=13717
  _globals['_FUNCTIONSTEPDEFINITION']._serialized_start=13720
  _globals['_FUNCTIONSTEPDEFINITION']._serialized_end=14040
  _globals['_CREATEFUNCTIONSTEP']._serialized_start=14043
  _globals['_CREATEFUNCTIONSTEP']._serialized_end=14183
  _globals['_UPDATEFUNCTIONSTEP']._serialized_start=14186
  _globals['_UPDATEFUNCTIONSTEP']._serialized_end=14364
  _globals['_CREATEFUNCTIONSTEPDEFINITION']._serialized_start=14367
  _globals['_CREATEFUNCTIONSTEPDEFINITION']._serialized_end=14570
  _globals['_UPDATEFUNCTIONSTEPDEFINITION']._serialized_start=14573
  _globals['_UPDATEFUNCTIONSTEPDEFINITION']._serialized_end=14857
# @@protoc_insertion_point(module_scope)
