# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: content_filter_settings.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x63ontent_filter_settings.proto\x12\x17\x63ontent_filter_settings\x1a\x1fgoogle/protobuf/timestamp.proto\"\xf8\x01\n\x15\x43ontentFilterSettings\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x41\n\x0c\x61zure_config\x18\x02 \x01(\x0b\x32+.content_filter_settings.AzureContentFilter\x12\x17\n\nupdated_by\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x33\n\nupdated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01\x88\x01\x01\x12\x15\n\x08\x64isabled\x18\x05 \x01(\x08H\x02\x88\x01\x01\x42\r\n\x0b_updated_byB\r\n\x0b_updated_atB\x0b\n\t_disabled\"B\n\x1a\x41zureContentFilterCategory\x12\x11\n\tis_active\x18\x01 \x01(\x08\x12\x11\n\tprecision\x18\x02 \x01(\t\"\xab\x02\n\x12\x41zureContentFilter\x12\x45\n\x08violence\x18\x01 \x01(\x0b\x32\x33.content_filter_settings.AzureContentFilterCategory\x12\x41\n\x04hate\x18\x02 \x01(\x0b\x32\x33.content_filter_settings.AzureContentFilterCategory\x12\x43\n\x06sexual\x18\x03 \x01(\x0b\x32\x33.content_filter_settings.AzureContentFilterCategory\x12\x46\n\tself_harm\x18\x04 \x01(\x0b\x32\x33.content_filter_settings.AzureContentFilterCategory\"\xcc\x01\n1ContentFilterSettings_UpdateContentFilterSettings\x12\x11\n\x04type\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x46\n\x0c\x61zure_config\x18\x02 \x01(\x0b\x32+.content_filter_settings.AzureContentFilterH\x01\x88\x01\x01\x12\x15\n\x08\x64isabled\x18\x03 \x01(\x08H\x02\x88\x01\x01\x42\x07\n\x05_typeB\x0f\n\r_azure_configB\x0b\n\t_disabledb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'content_filter_settings_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CONTENTFILTERSETTINGS']._serialized_start=92
  _globals['_CONTENTFILTERSETTINGS']._serialized_end=340
  _globals['_AZURECONTENTFILTERCATEGORY']._serialized_start=342
  _globals['_AZURECONTENTFILTERCATEGORY']._serialized_end=408
  _globals['_AZURECONTENTFILTER']._serialized_start=411
  _globals['_AZURECONTENTFILTER']._serialized_end=710
  _globals['_CONTENTFILTERSETTINGS_UPDATECONTENTFILTERSETTINGS']._serialized_start=713
  _globals['_CONTENTFILTERSETTINGS_UPDATECONTENTFILTERSETTINGS']._serialized_end=917
# @@protoc_insertion_point(module_scope)
