# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: asr_settings.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x61sr_settings.proto\x12\x0c\x61sr_settings\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc0\x01\n\x0b\x41SRSettings\x12\x10\n\x08\x62\x61rge_in\x18\x01 \x01(\x08\x12\x33\n\x0elatency_config\x18\x02 \x01(\x0b\x32\x1b.asr_settings.LatencyConfig\x12\x17\n\nupdated_by\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x33\n\nupdated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01\x88\x01\x01\x42\r\n\x0b_updated_byB\r\n\x0b_updated_at\"*\n\rLatencyConfig\x12\x19\n\x11interaction_style\x18\x01 \x01(\t\"\x90\x01\n\x1d\x41SRSettings_UpdateASRSettings\x12\x15\n\x08\x62\x61rge_in\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x38\n\x0elatency_config\x18\x02 \x01(\x0b\x32\x1b.asr_settings.LatencyConfigH\x01\x88\x01\x01\x42\x0b\n\t_barge_inB\x11\n\x0f_latency_configb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'asr_settings_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ASRSETTINGS']._serialized_start=70
  _globals['_ASRSETTINGS']._serialized_end=262
  _globals['_LATENCYCONFIG']._serialized_start=264
  _globals['_LATENCYCONFIG']._serialized_end=306
  _globals['_ASRSETTINGS_UPDATEASRSETTINGS']._serialized_start=309
  _globals['_ASRSETTINGS_UPDATEASRSETTINGS']._serialized_end=453
# @@protoc_insertion_point(module_scope)
