# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: variant.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rvariant.proto\x12\x07variant\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb1\x02\n\tAttribute\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\x0e\x61ttribute_type\x18\x03 \x01(\t\x12\x10\n\x08\x61rchived\x18\t \x01(\x08\x12\x30\n\nreferences\x18\x04 \x01(\x0b\x32\x1c.variant.AttributeReferences\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x06 \x01(\t\x12\x33\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x12\x17\n\nupdated_by\x18\x08 \x01(\tH\x01\x88\x01\x01\x42\r\n\x0b_updated_atB\r\n\x0b_updated_by\"\xe7\x01\n\x07Variant\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nis_default\x18\x05 \x01(\x08\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x07 \x01(\t\x12\x33\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x12\x17\n\nupdated_by\x18\t \x01(\tH\x01\x88\x01\x01\x42\r\n\x0b_updated_atB\r\n\x0b_updated_by\".\n\x08Variants\x12\"\n\x08variants\x18\x01 \x03(\x0b\x32\x10.variant.Variant\"\xa2\x01\n\x11VariantManagement\x12\"\n\x08variants\x18\x01 \x03(\x0b\x32\x10.variant.Variant\x12&\n\nattributes\x18\x02 \x03(\x0b\x32\x12.variant.Attribute\x12\x41\n\x18variant_attribute_values\x18\x03 \x01(\x0b\x32\x1f.variant.VariantAttributeValues\"\x9e\x01\n\x16VariantAttributeValues\x12;\n\x06values\x18\x01 \x03(\x0b\x32+.variant.VariantAttributeValues.ValuesEntry\x1aG\n\x0bValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.variant.AttributeValues:\x02\x38\x01\"v\n\x0f\x41ttributeValues\x12\x34\n\x06values\x18\x01 \x03(\x0b\x32$.variant.AttributeValues.ValuesEntry\x1a-\n\x0bValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"r\n\rVariantValues\x12\x32\n\x06values\x18\x01 \x03(\x0b\x32\".variant.VariantValues.ValuesEntry\x1a-\n\x0bValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xeb\x02\n\x13\x41ttributeReferences\x12\x38\n\x06topics\x18\x01 \x03(\x0b\x32(.variant.AttributeReferences.TopicsEntry\x12?\n\nflow_steps\x18\x02 \x03(\x0b\x32+.variant.AttributeReferences.FlowStepsEntry\x12\x44\n\rno_code_steps\x18\x03 \x03(\x0b\x32-.variant.AttributeReferences.NoCodeStepsEntry\x1a-\n\x0bTopicsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x30\n\x0e\x46lowStepsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x32\n\x10NoCodeStepsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"e\n\x15Variant_CreateVariant\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x32\n\x10\x61ttribute_values\x18\x03 \x01(\x0b\x32\x18.variant.AttributeValues\"\x8d\x01\n\x15Variant_UpdateVariant\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x37\n\x10\x61ttribute_values\x18\x03 \x01(\x0b\x32\x18.variant.AttributeValuesH\x01\x88\x01\x01\x42\x07\n\x05_nameB\x13\n\x11_attribute_values\"#\n\x15Variant_DeleteVariant\x12\n\n\x02id\x18\x01 \x01(\t\"\x95\x01\n\x17Variant_CreateAttribute\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x30\n\nreferences\x18\x03 \x01(\x0b\x32\x1c.variant.AttributeReferences\x12.\n\x0evariant_values\x18\x04 \x01(\x0b\x32\x16.variant.VariantValues\"\xcf\x01\n\x17Variant_UpdateAttribute\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x35\n\nreferences\x18\x03 \x01(\x0b\x32\x1c.variant.AttributeReferencesH\x01\x88\x01\x01\x12\x33\n\x0evariant_values\x18\x04 \x01(\x0b\x32\x16.variant.VariantValuesH\x02\x88\x01\x01\x42\x07\n\x05_nameB\r\n\x0b_referencesB\x11\n\x0f_variant_values\"%\n\x17Variant_DeleteAttribute\x12\n\n\x02id\x18\x01 \x01(\t\"\'\n\x19Variant_SetDefaultVariant\x12\n\n\x02id\x18\x01 \x01(\t\"K\n\x1bVariant_ImportVariantForCsv\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nis_default\x18\x03 \x01(\x08\"k\n\x1dVariant_ImportAttributeForCsv\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x30\n\nreferences\x18\x03 \x01(\x0b\x32\x1c.variant.AttributeReferences\"e\n*Variant_ImportVariantAttributeValuesForCsv\x12\x12\n\nvariant_id\x18\x01 \x01(\t\x12\x14\n\x0c\x61ttribute_id\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\x9f\x02\n\x16Variant_ImportVariants\x12\x36\n\x08variants\x18\x01 \x03(\x0b\x32$.variant.Variant_ImportVariantForCsv\x12:\n\nattributes\x18\x02 \x03(\x0b\x32&.variant.Variant_ImportAttributeForCsv\x12U\n\x18variant_attribute_values\x18\x03 \x03(\x0b\x32\x33.variant.Variant_ImportVariantAttributeValuesForCsv\x12\x1b\n\x13\x64\x65leted_variant_ids\x18\x04 \x03(\t\x12\x1d\n\x15\x64\x65leted_attribute_ids\x18\x05 \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'variant_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_VARIANTATTRIBUTEVALUES_VALUESENTRY']._options = None
  _globals['_VARIANTATTRIBUTEVALUES_VALUESENTRY']._serialized_options = b'8\001'
  _globals['_ATTRIBUTEVALUES_VALUESENTRY']._options = None
  _globals['_ATTRIBUTEVALUES_VALUESENTRY']._serialized_options = b'8\001'
  _globals['_VARIANTVALUES_VALUESENTRY']._options = None
  _globals['_VARIANTVALUES_VALUESENTRY']._serialized_options = b'8\001'
  _globals['_ATTRIBUTEREFERENCES_TOPICSENTRY']._options = None
  _globals['_ATTRIBUTEREFERENCES_TOPICSENTRY']._serialized_options = b'8\001'
  _globals['_ATTRIBUTEREFERENCES_FLOWSTEPSENTRY']._options = None
  _globals['_ATTRIBUTEREFERENCES_FLOWSTEPSENTRY']._serialized_options = b'8\001'
  _globals['_ATTRIBUTEREFERENCES_NOCODESTEPSENTRY']._options = None
  _globals['_ATTRIBUTEREFERENCES_NOCODESTEPSENTRY']._serialized_options = b'8\001'
  _globals['_ATTRIBUTE']._serialized_start=60
  _globals['_ATTRIBUTE']._serialized_end=365
  _globals['_VARIANT']._serialized_start=368
  _globals['_VARIANT']._serialized_end=599
  _globals['_VARIANTS']._serialized_start=601
  _globals['_VARIANTS']._serialized_end=647
  _globals['_VARIANTMANAGEMENT']._serialized_start=650
  _globals['_VARIANTMANAGEMENT']._serialized_end=812
  _globals['_VARIANTATTRIBUTEVALUES']._serialized_start=815
  _globals['_VARIANTATTRIBUTEVALUES']._serialized_end=973
  _globals['_VARIANTATTRIBUTEVALUES_VALUESENTRY']._serialized_start=902
  _globals['_VARIANTATTRIBUTEVALUES_VALUESENTRY']._serialized_end=973
  _globals['_ATTRIBUTEVALUES']._serialized_start=975
  _globals['_ATTRIBUTEVALUES']._serialized_end=1093
  _globals['_ATTRIBUTEVALUES_VALUESENTRY']._serialized_start=1048
  _globals['_ATTRIBUTEVALUES_VALUESENTRY']._serialized_end=1093
  _globals['_VARIANTVALUES']._serialized_start=1095
  _globals['_VARIANTVALUES']._serialized_end=1209
  _globals['_VARIANTVALUES_VALUESENTRY']._serialized_start=1048
  _globals['_VARIANTVALUES_VALUESENTRY']._serialized_end=1093
  _globals['_ATTRIBUTEREFERENCES']._serialized_start=1212
  _globals['_ATTRIBUTEREFERENCES']._serialized_end=1575
  _globals['_ATTRIBUTEREFERENCES_TOPICSENTRY']._serialized_start=1428
  _globals['_ATTRIBUTEREFERENCES_TOPICSENTRY']._serialized_end=1473
  _globals['_ATTRIBUTEREFERENCES_FLOWSTEPSENTRY']._serialized_start=1475
  _globals['_ATTRIBUTEREFERENCES_FLOWSTEPSENTRY']._serialized_end=1523
  _globals['_ATTRIBUTEREFERENCES_NOCODESTEPSENTRY']._serialized_start=1525
  _globals['_ATTRIBUTEREFERENCES_NOCODESTEPSENTRY']._serialized_end=1575
  _globals['_VARIANT_CREATEVARIANT']._serialized_start=1577
  _globals['_VARIANT_CREATEVARIANT']._serialized_end=1678
  _globals['_VARIANT_UPDATEVARIANT']._serialized_start=1681
  _globals['_VARIANT_UPDATEVARIANT']._serialized_end=1822
  _globals['_VARIANT_DELETEVARIANT']._serialized_start=1824
  _globals['_VARIANT_DELETEVARIANT']._serialized_end=1859
  _globals['_VARIANT_CREATEATTRIBUTE']._serialized_start=1862
  _globals['_VARIANT_CREATEATTRIBUTE']._serialized_end=2011
  _globals['_VARIANT_UPDATEATTRIBUTE']._serialized_start=2014
  _globals['_VARIANT_UPDATEATTRIBUTE']._serialized_end=2221
  _globals['_VARIANT_DELETEATTRIBUTE']._serialized_start=2223
  _globals['_VARIANT_DELETEATTRIBUTE']._serialized_end=2260
  _globals['_VARIANT_SETDEFAULTVARIANT']._serialized_start=2262
  _globals['_VARIANT_SETDEFAULTVARIANT']._serialized_end=2301
  _globals['_VARIANT_IMPORTVARIANTFORCSV']._serialized_start=2303
  _globals['_VARIANT_IMPORTVARIANTFORCSV']._serialized_end=2378
  _globals['_VARIANT_IMPORTATTRIBUTEFORCSV']._serialized_start=2380
  _globals['_VARIANT_IMPORTATTRIBUTEFORCSV']._serialized_end=2487
  _globals['_VARIANT_IMPORTVARIANTATTRIBUTEVALUESFORCSV']._serialized_start=2489
  _globals['_VARIANT_IMPORTVARIANTATTRIBUTEVALUESFORCSV']._serialized_end=2590
  _globals['_VARIANT_IMPORTVARIANTS']._serialized_start=2593
  _globals['_VARIANT_IMPORTVARIANTS']._serialized_end=2880
# @@protoc_insertion_point(module_scope)
