# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pronunciations.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14pronunciations.proto\x12\x0epronunciations\"\xed\x01\n\x07TTSRule\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05regex\x18\x02 \x01(\t\x12\x13\n\x0breplacement\x18\x03 \x01(\t\x12\x16\n\x0e\x63\x61se_sensitive\x18\x04 \x01(\x08\x12\x12\n\ncreated_at\x18\x05 \x01(\t\x12\x12\n\ncreated_by\x18\x06 \x01(\t\x12\x12\n\nupdated_at\x18\x07 \x01(\t\x12\x12\n\nupdated_by\x18\x08 \x01(\t\x12\x15\n\rlanguage_code\x18\t \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\n \x01(\t\x12\x10\n\x08position\x18\x0b \x01(\x05\x12\x0c\n\x04name\x18\x0c \x01(\t\"A\n\x0ePronunciations\x12/\n\x0epronunciations\x18\x01 \x03(\x0b\x32\x17.pronunciations.TTSRule\"\xb8\x01\n\"Pronunciations_CreatePronunciation\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05regex\x18\x02 \x01(\t\x12\x13\n\x0breplacement\x18\x03 \x01(\t\x12\x16\n\x0e\x63\x61se_sensitive\x18\x04 \x01(\x08\x12\x15\n\rlanguage_code\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\x10\n\x08position\x18\x07 \x01(\x05\x12\x0c\n\x04name\x18\x08 \x01(\t\"\xcc\x02\n\"Pronunciations_UpdatePronunciation\x12\x0f\n\x02id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05regex\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x18\n\x0breplacement\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x1b\n\x0e\x63\x61se_sensitive\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x1a\n\rlanguage_code\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x15\n\x08position\x18\x07 \x01(\x05H\x06\x88\x01\x01\x12\x11\n\x04name\x18\x08 \x01(\tH\x07\x88\x01\x01\x42\x05\n\x03_idB\x08\n\x06_regexB\x0e\n\x0c_replacementB\x11\n\x0f_case_sensitiveB\x10\n\x0e_language_codeB\x0e\n\x0c_descriptionB\x0b\n\t_positionB\x07\n\x05_name\"0\n\"Pronunciations_DeletePronunciation\x12\n\n\x02id\x18\x01 \x01(\t\"j\n$Pronunciations_ReorderPronunciations\x12\x42\n\rnew_positions\x18\x01 \x03(\x0b\x32+.pronunciations.PronunciationPositionUpdate\";\n\x1bPronunciationPositionUpdate\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08position\x18\x02 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'pronunciations_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TTSRULE']._serialized_start=41
  _globals['_TTSRULE']._serialized_end=278
  _globals['_PRONUNCIATIONS']._serialized_start=280
  _globals['_PRONUNCIATIONS']._serialized_end=345
  _globals['_PRONUNCIATIONS_CREATEPRONUNCIATION']._serialized_start=348
  _globals['_PRONUNCIATIONS_CREATEPRONUNCIATION']._serialized_end=532
  _globals['_PRONUNCIATIONS_UPDATEPRONUNCIATION']._serialized_start=535
  _globals['_PRONUNCIATIONS_UPDATEPRONUNCIATION']._serialized_end=867
  _globals['_PRONUNCIATIONS_DELETEPRONUNCIATION']._serialized_start=869
  _globals['_PRONUNCIATIONS_DELETEPRONUNCIATION']._serialized_end=917
  _globals['_PRONUNCIATIONS_REORDERPRONUNCIATIONS']._serialized_start=919
  _globals['_PRONUNCIATIONS_REORDERPRONUNCIATIONS']._serialized_end=1025
  _globals['_PRONUNCIATIONPOSITIONUPDATE']._serialized_start=1027
  _globals['_PRONUNCIATIONPOSITIONUPDATE']._serialized_end=1086
# @@protoc_insertion_point(module_scope)
