# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sms.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tsms.proto\x12\x03sms\x1a\x1fgoogle/protobuf/timestamp.proto\"H\n\x12SMSEnvPhoneNumbers\x12\x0f\n\x07sandbox\x18\x01 \x01(\t\x12\x13\n\x0bpre_release\x18\x02 \x01(\t\x12\x0c\n\x04live\x18\x03 \x01(\t\"\xdf\x02\n\x15SMSTemplateReferences\x12\x36\n\x06topics\x18\x01 \x03(\x0b\x32&.sms.SMSTemplateReferences.TopicsEntry\x12=\n\nflow_steps\x18\x02 \x03(\x0b\x32).sms.SMSTemplateReferences.FlowStepsEntry\x12<\n\tvariables\x18\x03 \x03(\x0b\x32).sms.SMSTemplateReferences.VariablesEntry\x1a-\n\x0bTopicsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x30\n\x0e\x46lowStepsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x30\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"*\n\x03SMS\x12#\n\ttemplates\x18\x01 \x03(\x0b\x32\x10.sms.SMSTemplate\"\xd9\x02\n\x0bSMSTemplate\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04text\x18\x03 \x01(\t\x12\x32\n\x11\x65nv_phone_numbers\x18\x04 \x01(\x0b\x32\x17.sms.SMSEnvPhoneNumbers\x12.\n\nreferences\x18\x05 \x01(\x0b\x32\x1a.sms.SMSTemplateReferences\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x07 \x01(\t\x12\x33\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x12\x17\n\nupdated_by\x18\t \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06\x61\x63tive\x18\n \x01(\x08\x42\r\n\x0b_updated_atB\r\n\x0b_updated_by\"\xb0\x01\n\x12SMS_CreateTemplate\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04text\x18\x03 \x01(\t\x12\x32\n\x11\x65nv_phone_numbers\x18\x04 \x01(\x0b\x32\x17.sms.SMSEnvPhoneNumbers\x12.\n\nreferences\x18\x05 \x01(\x0b\x32\x1a.sms.SMSTemplateReferences\x12\x0e\n\x06\x61\x63tive\x18\x06 \x01(\x08\"\x82\x01\n\x18UpdateSMSEnvPhoneNumbers\x12\x14\n\x07sandbox\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0bpre_release\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x11\n\x04live\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\n\n\x08_sandboxB\x0e\n\x0c_pre_releaseB\x07\n\x05_live\"\x91\x02\n\x12SMS_UpdateTemplate\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04text\x18\x03 \x01(\tH\x01\x88\x01\x01\x12=\n\x11\x65nv_phone_numbers\x18\x04 \x01(\x0b\x32\x1d.sms.UpdateSMSEnvPhoneNumbersH\x02\x88\x01\x01\x12\x33\n\nreferences\x18\x05 \x01(\x0b\x32\x1a.sms.SMSTemplateReferencesH\x03\x88\x01\x01\x12\x13\n\x06\x61\x63tive\x18\x06 \x01(\x08H\x04\x88\x01\x01\x42\x07\n\x05_nameB\x07\n\x05_textB\x14\n\x12_env_phone_numbersB\r\n\x0b_referencesB\t\n\x07_active\" \n\x12SMS_DeleteTemplate\x12\n\n\x02id\x18\x01 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sms_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SMSTEMPLATEREFERENCES_TOPICSENTRY']._options = None
  _globals['_SMSTEMPLATEREFERENCES_TOPICSENTRY']._serialized_options = b'8\001'
  _globals['_SMSTEMPLATEREFERENCES_FLOWSTEPSENTRY']._options = None
  _globals['_SMSTEMPLATEREFERENCES_FLOWSTEPSENTRY']._serialized_options = b'8\001'
  _globals['_SMSTEMPLATEREFERENCES_VARIABLESENTRY']._options = None
  _globals['_SMSTEMPLATEREFERENCES_VARIABLESENTRY']._serialized_options = b'8\001'
  _globals['_SMSENVPHONENUMBERS']._serialized_start=51
  _globals['_SMSENVPHONENUMBERS']._serialized_end=123
  _globals['_SMSTEMPLATEREFERENCES']._serialized_start=126
  _globals['_SMSTEMPLATEREFERENCES']._serialized_end=477
  _globals['_SMSTEMPLATEREFERENCES_TOPICSENTRY']._serialized_start=332
  _globals['_SMSTEMPLATEREFERENCES_TOPICSENTRY']._serialized_end=377
  _globals['_SMSTEMPLATEREFERENCES_FLOWSTEPSENTRY']._serialized_start=379
  _globals['_SMSTEMPLATEREFERENCES_FLOWSTEPSENTRY']._serialized_end=427
  _globals['_SMSTEMPLATEREFERENCES_VARIABLESENTRY']._serialized_start=429
  _globals['_SMSTEMPLATEREFERENCES_VARIABLESENTRY']._serialized_end=477
  _globals['_SMS']._serialized_start=479
  _globals['_SMS']._serialized_end=521
  _globals['_SMSTEMPLATE']._serialized_start=524
  _globals['_SMSTEMPLATE']._serialized_end=869
  _globals['_SMS_CREATETEMPLATE']._serialized_start=872
  _globals['_SMS_CREATETEMPLATE']._serialized_end=1048
  _globals['_UPDATESMSENVPHONENUMBERS']._serialized_start=1051
  _globals['_UPDATESMSENVPHONENUMBERS']._serialized_end=1181
  _globals['_SMS_UPDATETEMPLATE']._serialized_start=1184
  _globals['_SMS_UPDATETEMPLATE']._serialized_end=1457
  _globals['_SMS_DELETETEMPLATE']._serialized_start=1459
  _globals['_SMS_DELETETEMPLATE']._serialized_end=1491
# @@protoc_insertion_point(module_scope)
