# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bundle.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from poly.handlers.protobuf import snapshot_pb2 as snapshot__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x62undle.proto\x1a\x0esnapshot.proto\x1a\x1cgoogle/protobuf/struct.proto\"\x95\x01\n\x0bRagDatabase\x12\x17\n\x0f\x65mbedding_model\x18\x01 \x01(\t\x12\x37\n\x0e\x65mbeddings_map\x18\x02 \x03(\x0b\x32\x1f.RagDatabase.EmbeddingsMapEntry\x1a\x34\n\x12\x45mbeddingsMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"i\n\x15RealTimeConfiguration\x12\'\n\x06schema\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\'\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xdd\x01\n\x06\x42undle\x12$\n\x08snapshot\x18\x01 \x01(\x0b\x32\x12.snapshot.Snapshot\x12\x38\n\x11rt_configurations\x18\x02 \x03(\x0b\x32\x1d.Bundle.RtConfigurationsEntry\x12\"\n\x0crag_database\x18\x03 \x01(\x0b\x32\x0c.RagDatabase\x1aO\n\x15RtConfigurationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.RealTimeConfiguration:\x02\x38\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bundle_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_RAGDATABASE_EMBEDDINGSMAPENTRY']._options = None
  _globals['_RAGDATABASE_EMBEDDINGSMAPENTRY']._serialized_options = b'8\001'
  _globals['_BUNDLE_RTCONFIGURATIONSENTRY']._options = None
  _globals['_BUNDLE_RTCONFIGURATIONSENTRY']._serialized_options = b'8\001'
  _globals['_RAGDATABASE']._serialized_start=63
  _globals['_RAGDATABASE']._serialized_end=212
  _globals['_RAGDATABASE_EMBEDDINGSMAPENTRY']._serialized_start=160
  _globals['_RAGDATABASE_EMBEDDINGSMAPENTRY']._serialized_end=212
  _globals['_REALTIMECONFIGURATION']._serialized_start=214
  _globals['_REALTIMECONFIGURATION']._serialized_end=319
  _globals['_BUNDLE']._serialized_start=322
  _globals['_BUNDLE']._serialized_end=543
  _globals['_BUNDLE_RTCONFIGURATIONSENTRY']._serialized_start=464
  _globals['_BUNDLE_RTCONFIGURATIONSENTRY']._serialized_end=543
# @@protoc_insertion_point(module_scope)
