# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tts_settings.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12tts_settings.proto\x12\x0ctts_settings\x1a\x1fgoogle/protobuf/timestamp.proto\"\x90\x01\n\x0bTTSSettings\x12\x15\n\rlanguage_code\x18\x01 \x01(\t\x12\x17\n\nupdated_by\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x33\n\nupdated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01\x88\x01\x01\x42\r\n\x0b_updated_byB\r\n\x0b_updated_at\"6\n\x1dTTSSettings_UpdateTTSSettings\x12\x15\n\rlanguage_code\x18\x01 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tts_settings_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TTSSETTINGS']._serialized_start=70
  _globals['_TTSSETTINGS']._serialized_end=214
  _globals['_TTSSETTINGS_UPDATETTSSETTINGS']._serialized_start=216
  _globals['_TTSSETTINGS_UPDATETTSSETTINGS']._serialized_end=270
# @@protoc_insertion_point(module_scope)
