# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: artifact.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from agent_v2 import agent_pb2 as agent__v2_dot_agent__pb2
from agent_v3.genai.proto.integrations import integrations_pb2 as agent__v3_dot_genai_dot_proto_dot_integrations_dot_integrations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x61rtifact.proto\x12\x08\x61rtifact\x1a\x14\x61gent_v2/agent.proto\x1a\x34\x61gent_v3/genai/proto/integrations/integrations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xfe\n\n\x0c\x43oreArtifact\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x30\n\x0clast_updated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12;\n\x14\x66unctions_deployment\x18\x03 \x01(\x0b\x32\x1d.artifact.FunctionsDeployment\x12\x39\n\x13\x63onversation_limits\x18\x04 \x01(\x0b\x32\x1c.artifact.ConversationLimits\x12\x1e\n\x05voice\x18\x05 \x01(\x0b\x32\x0f.artifact.Voice\x12\x1a\n\x03\x61sr\x18\x0f \x01(\x0b\x32\r.artifact.Asr\x12\x1e\n\x05model\x18\x06 \x01(\x0b\x32\x0f.artifact.Model\x12\x33\n\x10\x61ssistant_config\x18\x07 \x01(\x0b\x32\x19.artifact.AssistantConfig\x12/\n\x0eknowledge_base\x18\x08 \x01(\x0b\x32\x17.artifact.KnowledgeBase\x12%\n\tfunctions\x18\t \x03(\x0b\x32\x12.artifact.Function\x12*\n\x0estart_function\x18\r \x01(\x0b\x32\x12.artifact.Function\x12#\n\x08handoffs\x18\n \x03(\x0b\x32\x11.artifact.Handoff\x12<\n\x15voice_tuning_settings\x18\x0b \x03(\x0b\x32\x1d.artifact.VoiceTuningSettings\x12,\n\rsms_templates\x18\x0c \x03(\x0b\x32\x15.artifact.SMSTemplate\x12\x1e\n\x05\x66lows\x18\x0e \x01(\x0b\x32\x0f.artifact.Flows\x12\x31\n\rintro_message\x18\x10 \x01(\x0b\x32\x16.artifact.IntroMessageB\x02\x18\x01\x12-\n\rstop_keywords\x18\x11 \x03(\x0b\x32\x16.artifact.StopKeywords\x12#\n\x08variants\x18\x12 \x03(\x0b\x32\x11.artifact.Variant\x12\x36\n\x12variant_attributes\x18\x13 \x03(\x0b\x32\x1a.artifact.VariantAttribute\x12(\n\x0c\x65nd_function\x18\x14 \x01(\x0b\x32\x12.artifact.Function\x12\x35\n\x0f\x64\x65ployed_voices\x18\x15 \x01(\x0b\x32\x18.artifact.DeployedVoicesB\x02\x18\x01\x12$\n\x08\x65ntities\x18\x16 \x01(\x0b\x32\x12.artifact.Entities\x12\x33\n\x10\x61pi_integrations\x18\x17 \x01(\x0b\x32\x19.artifact.ApiIntegrations\x12&\n\tvariables\x18\x18 \x01(\x0b\x32\x13.artifact.Variables\x12+\n\x0b\x64isclaimers\x18\x19 \x03(\x0b\x32\x16.artifact.IntroMessage\x12.\n\x0c\x61gent_voices\x18\x1a \x03(\x0b\x32\x18.artifact.DeployedVoices\x12H\n\x1bmultilingual_agent_settings\x18\x1b \x01(\x0b\x32#.artifact.MultilingualAgentSettings\x12\x45\n\x19multilingual_translations\x18\x1c \x01(\x0b\x32\".artifact.MultilingualTranslations\x12$\n\x08\x63hannels\x18\x1d \x01(\x0b\x32\x12.artifact.Channels\x12\x39\n\x0cintegrations\x18\x1e \x01(\x0b\x32#.artifact.integrations.Integrations\"\x89\x01\n\x14VoiceWithProbability\x12\x1e\n\x05voice\x18\x01 \x01(\x0b\x32\x0f.artifact.Voice\x12\x13\n\x0bprobability\x18\x02 \x01(\x02\x12<\n\x15voice_tuning_settings\x18\x03 \x01(\x0b\x32\x1d.artifact.VoiceTuningSettings\".\n\x08\x45ntities\x12\"\n\x08\x65ntities\x18\x01 \x03(\x0b\x32\x10.artifact.Entity\"\xe4\x04\n\x06\x45ntity\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x41\n\x13\x61lphanumeric_config\x18\x06 \x01(\x0b\x32\".artifact.AlphanumericEntityConfigH\x00\x12\x35\n\rnumber_config\x18\x05 \x01(\x0b\x32\x1c.artifact.NumberEntityConfigH\x00\x12\x31\n\x0b\x64\x61te_config\x18\x08 \x01(\x0b\x32\x1a.artifact.DateEntityConfigH\x00\x12\x31\n\x0btime_config\x18\t \x01(\x0b\x32\x1a.artifact.TimeEntityConfigH\x00\x12@\n\x13phone_number_config\x18\n \x01(\x0b\x32!.artifact.PhoneNumberEntityConfigH\x00\x12\x31\n\x0bname_config\x18\x0b \x01(\x0b\x32\x1a.artifact.NameEntityConfigH\x00\x12\x37\n\x0e\x61\x64\x64ress_config\x18\x0c \x01(\x0b\x32\x1d.artifact.AddressEntityConfigH\x00\x12:\n\x10\x66ree_text_config\x18\r \x01(\x0b\x32\x1e.artifact.FreeTextEntityConfigH\x00\x12H\n\x17multiple_options_config\x18\x0e \x01(\x0b\x32%.artifact.MultipleOptionsEntityConfigH\x00\x42\t\n\x07\x64\x65tails\"2\n\tVariables\x12%\n\tvariables\x18\x01 \x03(\x0b\x32\x12.artifact.Variable\"\xac\x01\n\x08Variable\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\ncreated_by\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\x05 \x01(\t\x12.\n\nupdated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"D\n\x12NumberEntityConfig\x12\x0b\n\x03min\x18\x01 \x01(\x02\x12\x0b\n\x03max\x18\x02 \x01(\x02\x12\x14\n\x0cnumeric_type\x18\x03 \x01(\t\")\n\x18\x41lphanumericEntityConfig\x12\r\n\x05regex\x18\x01 \x01(\t\".\n\x1bMultipleOptionsEntityConfig\x12\x0f\n\x07options\x18\x01 \x03(\t\"K\n\x10\x44\x61teEntityConfig\x12\x11\n\tday_first\x18\x01 \x01(\x08\x12\x12\n\nstart_date\x18\x02 \x01(\t\x12\x10\n\x08\x65nd_date\x18\x03 \x01(\t\"0\n\x17PhoneNumberEntityConfig\x12\x15\n\rcountry_codes\x18\x01 \x03(\t\"8\n\x10TimeEntityConfig\x12\x12\n\nstart_time\x18\x01 \x01(\t\x12\x10\n\x08\x65nd_time\x18\x02 \x01(\t\"\x12\n\x10NameEntityConfig\"\x15\n\x13\x41\x64\x64ressEntityConfig\"\x16\n\x14\x46reeTextEntityConfig\"b\n\x0e\x44\x65ployedVoices\x12\x39\n\x11voices_with_proba\x18\x01 \x03(\x0b\x32\x1e.artifact.VoiceWithProbability\x12\x15\n\rlanguage_code\x18\x02 \x01(\t\"J\n\x12\x43onversationLimits\x12\x1b\n\x13\x63\x61ll_duration_limit\x18\x01 \x01(\r\x12\x17\n\x0f\x63hat_turn_limit\x18\x02 \x01(\r\"]\n\x05Voice\x12\x19\n\x11provider_voice_id\x18\x01 \x01(\t\x12\x10\n\x08provider\x18\x02 \x01(\t\x12\'\n\x06\x63onfig\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"g\n\x03\x41sr\x12\x13\n\x0bprovider_id\x18\x01 \x01(\t\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x10\n\x08language\x18\x03 \x01(\t\x12\'\n\x06\x63onfig\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\"\\\n\x07TTSRule\x12\r\n\x05regex\x18\x01 \x01(\t\x12\x13\n\x0breplacement\x18\x02 \x01(\t\x12\x16\n\x0e\x63\x61se_sensitive\x18\x03 \x01(\x08\x12\x15\n\rlanguage_code\x18\x04 \x01(\t\"K\n\x05Model\x12\x19\n\x11provider_model_id\x18\x01 \x01(\t\x12\'\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"\x92\x04\n\x0f\x41ssistantConfig\x12.\n\nupdated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\x02 \x01(\t\x12\x1a\n\x12\x64\x65\x66\x61ult_handoff_id\x18\x03 \x01(\t\x12\x10\n\x08model_id\x18\x04 \x01(\t\x12\x10\n\x08voice_id\x18\x05 \x01(\t\x12\'\n\x06\x63onfig\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06\x61sr_id\x18\x07 \x01(\t\x12$\n\ttts_rules\x18\x08 \x03(\x0b\x32\x11.artifact.TTSRule\x12/\n\x0e\x63ontent_filter\x18\t \x01(\x0b\x32\x17.artifact.ContentFilter\x12\x30\n\x0f\x62\x61rge_in_config\x18\n \x01(\x0b\x32\x17.artifact.BargeInConfig\x12/\n\x0elatency_config\x18\x0b \x01(\x0b\x32\x17.artifact.LatencyConfig\x12.\n\x0e\x61sr_keyphrases\x18\x0c \x03(\x0b\x32\x16.artifact.AsrKeyphrase\x12\x30\n\x0f\x61sr_corrections\x18\r \x03(\x0b\x32\x17.artifact.AsrCorrection\x12&\n\tlanguages\x18\x0e \x01(\x0b\x32\x13.artifact.Languages\"\x89\x01\n\x05Rules\x12\x11\n\tbehaviour\x18\x01 \x01(\t\x12\x15\n\rsystem_prompt\x18\x02 \x01(\t\x12\x11\n\tfunctions\x18\x03 \x03(\t\x12\x10\n\x08handoffs\x18\x04 \x03(\t\x12\x15\n\rsms_templates\x18\x05 \x03(\t\x12\x1a\n\x12variant_attributes\x18\x06 \x03(\t\"c\n\x0bPersonality\x12\x12\n\nadjectives\x18\x01 \x03(\t\x12\x0e\n\x06\x63ustom\x18\x02 \x01(\t\x12\x30\n\x0f\x61\x64jectives_dict\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\">\n\x04Role\x12\r\n\x05value\x18\x01 \x01(\t\x12\x17\n\x0f\x61\x64\x64itional_info\x18\x02 \x01(\t\x12\x0e\n\x06\x63ustom\x18\x03 \x01(\t\"\x81\x01\n\x15KnowledgeBaseMetadata\x12\x1e\n\x05rules\x18\x01 \x01(\x0b\x32\x0f.artifact.Rules\x12*\n\x0bpersonality\x18\x02 \x01(\x0b\x32\x15.artifact.Personality\x12\x1c\n\x04role\x18\x03 \x01(\x0b\x32\x0e.artifact.Role\"\xf1\x01\n\rKnowledgeBase\x12.\n\nupdated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\x02 \x01(\t\x12\x17\n\x0fwelcome_message\x18\x03 \x01(\t\x12\x37\n\x0eknowledge_base\x18\x04 \x01(\x0b\x32\x1f.artifact.KnowledgeBaseMetadata\x12\x33\n\x12\x61\x64\x64itional_context\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x15\n\rsystem_prompt\x18\x06 \x01(\t\"D\n\x11\x46unctionParameter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\"2\n\rDelayResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x10\n\x08\x64uration\x18\x02 \x01(\r\"k\n\x0eLatencyControl\x12\x15\n\rinitial_delay\x18\x01 \x01(\r\x12\x10\n\x08interval\x18\x02 \x01(\r\x12\x30\n\x0f\x64\x65lay_responses\x18\x03 \x03(\x0b\x32\x17.artifact.DelayResponse\"\xe0\x01\n\x08\x46unction\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x66unction_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12/\n\nparameters\x18\x05 \x03(\x0b\x32\x1b.artifact.FunctionParameter\x12\x17\n\x0f\x61ssociated_flow\x18\x06 \x01(\t\x12\x31\n\x0flatency_control\x18\x07 \x01(\x0b\x32\x18.artifact.LatencyControl\x12\x13\n\x0bprefix_path\x18\x08 \x01(\t\"=\n\x13\x46unctionsDeployment\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1a\n\x12\x64\x65ployment_version\x18\x02 \x01(\t\"\xe0\x02\n\x07Handoff\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x04 \x01(\t\x12.\n\nupdated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12\x11\n\textension\x18\x08 \x01(\t\x12)\n\x06invite\x18\n \x01(\x0b\x32\x17.agent_v2.InviteHandoffH\x00\x12\'\n\x05refer\x18\x0b \x01(\x0b\x32\x16.agent_v2.ReferHandoffH\x00\x12#\n\x03\x62ye\x18\x0c \x01(\x0b\x32\x14.agent_v2.ByeHandoffH\x00\x42\x0c\n\nsip_configJ\x04\x08\t\x10\n\"\xfb\x01\n\x13VoiceTuningSettings\x12\x18\n\x10genai_project_id\x18\x01 \x01(\t\x12\x17\n\x0fvoice_config_id\x18\x02 \x01(\t\x12)\n\x08settings\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_by\x18\x04 \x01(\t\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\x06 \x01(\t\x12.\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"C\n\rSMSEnvNumbers\x12\x0f\n\x07sandbox\x18\x01 \x01(\t\x12\x13\n\x0bpre_release\x18\x02 \x01(\t\x12\x0c\n\x04live\x18\x03 \x01(\t\"\xfd\x01\n\x0bSMSTemplate\x12\n\n\x02id\x18\x01 \x01(\t\x12\x15\n\rtemplate_name\x18\x02 \x01(\t\x12\x15\n\rtemplate_text\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x05 \x01(\t\x12.\n\nupdated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\x07 \x01(\t\x12,\n\x0bsms_numbers\x18\x08 \x01(\x0b\x32\x17.artifact.SMSEnvNumbers\"=\n\x11\x46unctionReference\x12\x13\n\x0b\x66unction_id\x18\x01 \x01(\t\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\"\"\n\nStepLayout\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\"\xa9\x02\n\x08\x46lowStep\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x39\n\x14\x66unctions_referenced\x18\x03 \x03(\x0b\x32\x1b.artifact.FunctionReference\x12$\n\x06layout\x18\x04 \x01(\x0b\x32\x14.artifact.StepLayout\x12:\n\x12\x61sr_biasing_config\x18\x05 \x01(\x0b\x32\x1e.artifact.StepAsrBiasingConfig\x12-\n\x0b\x64tmf_config\x18\x06 \x01(\x0b\x32\x18.artifact.StepDTMFConfig\x12\x32\n\x0finitial_timeout\x18\x07 \x01(\x0b\x32\x19.google.protobuf.Duration\"U\n\x0c\x46unctionStep\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x37\n\x12\x66unction_reference\x18\x02 \x01(\x0b\x32\x1b.artifact.FunctionReference\"\xa3\x01\n\rFlowStartStep\x12+\n\radvanced_step\x18\x01 \x01(\x0b\x32\x12.artifact.FlowStepH\x00\x12,\n\x0cno_code_step\x18\x02 \x01(\x0b\x32\x14.artifact.NoCodeStepH\x00\x12/\n\rfunction_step\x18\x03 \x01(\x0b\x32\x16.artifact.FunctionStepH\x00\x42\x06\n\x04step\"\x9a\x01\n\x04Step\x12+\n\radvanced_step\x18\x01 \x01(\x0b\x32\x12.artifact.FlowStepH\x00\x12,\n\x0cno_code_step\x18\x02 \x01(\x0b\x32\x14.artifact.NoCodeStepH\x00\x12/\n\rfunction_step\x18\x03 \x01(\x0b\x32\x16.artifact.FunctionStepH\x00\x42\x06\n\x04step\"p\n\x1aNoCodeStepConditionDetails\x12\r\n\x05label\x18\x01 \x01(\t\x12\x18\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x11required_entities\x18\x03 \x03(\tB\x0e\n\x0c_description\"M\n\x14NoCodeStepReferences\x12\x35\n\x07\x64\x65tails\x18\x01 \x01(\x0b\x32$.artifact.NoCodeStepConditionDetails\"J\n\x11\x45xitFlowCondition\x12\x35\n\x07\x64\x65tails\x18\x01 \x01(\x0b\x32$.artifact.NoCodeStepConditionDetails\"W\n\x1c\x46unctionStepConditionDetails\x12\r\n\x05label\x18\x01 \x01(\t\x12\x18\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0e\n\x0c_description\"c\n\x11\x46lowStepCondition\x12\x35\n\x07\x64\x65tails\x18\x01 \x01(\x0b\x32$.artifact.NoCodeStepConditionDetails\x12\x17\n\x0f\x63hild_step_name\x18\x02 \x01(\t\"e\n\x13NoCodeStepCondition\x12\x35\n\x07\x64\x65tails\x18\x01 \x01(\x0b\x32$.artifact.NoCodeStepConditionDetails\x12\x17\n\x0f\x63hild_step_name\x18\x02 \x01(\t\"i\n\x15\x46unctionStepCondition\x12\x37\n\x07\x64\x65tails\x18\x01 \x01(\x0b\x32&.artifact.FunctionStepConditionDetails\x12\x17\n\x0f\x63hild_step_name\x18\x02 \x01(\t\"\x8d\x02\n\tCondition\x12:\n\x13\x65xit_flow_condition\x18\x02 \x01(\x0b\x32\x1b.artifact.ExitFlowConditionH\x00\x12\x35\n\x0estep_condition\x18\x03 \x01(\x0b\x32\x1b.artifact.FlowStepConditionH\x00\x12?\n\x16no_code_step_condition\x18\x04 \x01(\x0b\x32\x1d.artifact.NoCodeStepConditionH\x00\x12\x42\n\x17\x66unction_step_condition\x18\x05 \x01(\x0b\x32\x1f.artifact.FunctionStepConditionH\x00\x42\x08\n\x06\x63onfig\"n\n\nNoCodeStep\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06prompt\x18\x02 \x01(\t\x12\x19\n\x11\x65ntity_references\x18\x03 \x03(\t\x12\'\n\nconditions\x18\x04 \x03(\x0b\x32\x13.artifact.Condition\"\x88\x02\n\x14StepAsrBiasingConfig\x12\x14\n\x0c\x61lphanumeric\x18\x01 \x01(\x08\x12\x15\n\rname_spelling\x18\x02 \x01(\x08\x12\x0f\n\x07numeric\x18\x03 \x01(\x08\x12\x12\n\nparty_size\x18\x04 \x01(\x08\x12\x14\n\x0cprecise_date\x18\x05 \x01(\x08\x12\x15\n\rrelative_date\x18\x06 \x01(\x08\x12\x15\n\rsingle_number\x18\x07 \x01(\x08\x12\x0c\n\x04time\x18\x08 \x01(\x08\x12\x0e\n\x06yes_no\x18\t \x01(\x08\x12\x17\n\x0f\x63ustom_keywords\x18\n \x03(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x0b \x01(\x08\x12\x12\n\nis_enabled\x18\x0c \x01(\x08\"\xb7\x01\n\x0eStepDTMFConfig\x12\x12\n\nis_enabled\x18\x01 \x01(\x08\x12\x36\n\x13inter_digit_timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x12\n\nmax_digits\x18\x03 \x01(\r\x12\x0f\n\x07\x65nd_key\x18\x04 \x01(\t\x12$\n\x1c\x63ollect_while_agent_speaking\x18\x05 \x01(\x08\x12\x0e\n\x06is_pii\x18\x06 \x01(\x08\"\xcd\x03\n\x04\x46low\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12*\n\nstart_step\x18\x04 \x01(\x0b\x32\x12.artifact.FlowStepB\x02\x18\x01\x12%\n\x05steps\x18\x05 \x03(\x0b\x32\x12.artifact.FlowStepB\x02\x18\x01\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x07 \x01(\t\x12.\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\t \x01(\t\x12\x34\n\x12no_code_start_step\x18\n \x01(\x0b\x32\x14.artifact.NoCodeStepB\x02\x18\x01\x12/\n\rno_code_steps\x18\x0b \x03(\x0b\x32\x14.artifact.NoCodeStepB\x02\x18\x01\x12\x30\n\x0f\x66low_start_step\x18\x0e \x01(\x0b\x32\x17.artifact.FlowStartStep\x12\"\n\nflow_steps\x18\x0f \x03(\x0b\x32\x0e.artifact.Step\"*\n\x05\x46lows\x12!\n\tflow_list\x18\x01 \x03(\x0b\x32\x0e.artifact.Flow\"9\n\x0b\x41udioToPlay\x12\x0f\n\x07s3_path\x18\x01 \x01(\t\x12\x19\n\x11original_filename\x18\x02 \x01(\t\"\x9b\x02\n\x0cIntroMessage\x12\x1a\n\x12\x64isclaimer_enabled\x18\x01 \x01(\x08\x12\x1a\n\x12\x64isclaimer_message\x18\x02 \x01(\t\x12)\n\x10\x64isclaimer_voice\x18\x03 \x01(\x0b\x32\x0f.artifact.Voice\x12\x1b\n\x13\x64isclaimer_voice_id\x18\x04 \x01(\t\x12G\n disclaimer_voice_tuning_settings\x18\x05 \x03(\x0b\x32\x1d.artifact.VoiceTuningSettings\x12+\n\x0cringing_tone\x18\x06 \x01(\x0b\x32\x15.artifact.AudioToPlay\x12\x15\n\rlanguage_code\x18\x07 \x01(\t\"B\n\x1a\x41zureContentFilterCategory\x12\x11\n\tis_active\x18\x01 \x01(\x08\x12\x11\n\tprecision\x18\x02 \x01(\t\"\xef\x01\n\x12\x41zureContentFilter\x12\x36\n\x08violence\x18\x01 \x01(\x0b\x32$.artifact.AzureContentFilterCategory\x12\x32\n\x04hate\x18\x02 \x01(\x0b\x32$.artifact.AzureContentFilterCategory\x12\x34\n\x06sexual\x18\x03 \x01(\x0b\x32$.artifact.AzureContentFilterCategory\x12\x37\n\tself_harm\x18\x04 \x01(\x0b\x32$.artifact.AzureContentFilterCategory\"c\n\rContentFilter\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x32\n\x0c\x61zure_config\x18\x02 \x01(\x0b\x32\x1c.artifact.AzureContentFilter\x12\x10\n\x08\x64isabled\x18\x03 \x01(\x08\")\n\rLatencyConfig\x12\x18\n\x10interaction_type\x18\x01 \x01(\t\" \n\rBargeInConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"\xa3\x02\n\x0cStopKeywords\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\ncreated_by\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\x04 \x01(\t\x12.\n\nupdated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05title\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12\x1b\n\x13regular_expressions\x18\x08 \x03(\t\x12\x12\n\nsay_phrase\x18\t \x01(\x08\x12\x13\n\x0b\x66unction_id\x18\n \x01(\t\x12\x15\n\rlanguage_code\x18\x0b \x01(\t\"0\n\x0c\x41srKeyphrase\x12\x11\n\tkeyphrase\x18\x01 \x01(\t\x12\r\n\x05level\x18\x02 \x01(\t\"\xbf\x01\n\x07Variant\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\ncreated_by\x18\x04 \x01(\t\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\x06 \x01(\t\x12.\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nis_default\x18\x08 \x01(\x08\"\xf5\x01\n\x10VariantAttribute\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\x0e\x61ttribute_type\x18\x03 \x01(\t\x12\x12\n\ncreated_by\x18\x04 \x01(\t\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\x06 \x01(\t\x12.\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x06values\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\"\x86\x01\n\rAsrCorrection\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x46\n\x13regular_expressions\x18\x04 \x03(\x0b\x32).artifact.AsrCorrectionRegularExpressions\"l\n\x1f\x41srCorrectionRegularExpressions\x12\x1a\n\x12regular_expression\x18\x01 \x01(\t\x12\x13\n\x0breplacement\x18\x02 \x01(\t\x12\x18\n\x10replacement_type\x18\x03 \x01(\t\"E\n\x0f\x41piIntegrations\x12\x32\n\x10\x61pi_integrations\x18\x01 \x03(\x0b\x32\x18.artifact.ApiIntegration\"\xa4\x01\n\x0e\x41piIntegration\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12,\n\x0c\x65nvironments\x18\x04 \x01(\x0b\x32\x16.artifact.Environments\x12\x35\n\noperations\x18\x05 \x03(\x0b\x32!.artifact.ApiIntegrationOperation\"\xa2\x01\n\x0c\x45nvironments\x12/\n\x07sandbox\x18\x01 \x01(\x0b\x32\x1e.artifact.ApiIntegrationConfig\x12\x33\n\x0bpre_release\x18\x02 \x01(\x0b\x32\x1e.artifact.ApiIntegrationConfig\x12,\n\x04live\x18\x03 \x01(\x0b\x32\x1e.artifact.ApiIntegrationConfig\"A\n\x14\x41piIntegrationConfig\x12\x10\n\x08\x62\x61se_url\x18\x01 \x01(\t\x12\x11\n\tauth_type\x18\x02 \x01(\tJ\x04\x08\x03\x10\x04\"U\n\x17\x41piIntegrationOperation\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06method\x18\x03 \x01(\t\x12\x10\n\x08resource\x18\x04 \x01(\t\"\x18\n\x08Language\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\"k\n\tLanguages\x12,\n\x10\x64\x65\x66\x61ult_language\x18\x01 \x01(\x0b\x32\x12.artifact.Language\x12\x30\n\x14\x61\x64\x64itional_languages\x18\x02 \x03(\x0b\x32\x12.artifact.Language\"B\n\x10LanguageBehavior\x12\x17\n\x0f\x62\x65havior_prompt\x18\x01 \x01(\t\x12\x15\n\rlanguage_code\x18\x02 \x01(\t\":\n\x08Greeting\x12\x17\n\x0fwelcome_message\x18\x01 \x01(\t\x12\x15\n\rlanguage_code\x18\x02 \x01(\t\"\xd6\x02\n\x19MultilingualAgentSettings\x12V\n\x12language_behaviors\x18\x01 \x03(\x0b\x32:.artifact.MultilingualAgentSettings.LanguageBehaviorsEntry\x12\x45\n\tgreetings\x18\x02 \x03(\x0b\x32\x32.artifact.MultilingualAgentSettings.GreetingsEntry\x1aT\n\x16LanguageBehaviorsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.artifact.LanguageBehavior:\x02\x38\x01\x1a\x44\n\x0eGreetingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.artifact.Greeting:\x02\x38\x01\"\x1d\n\rLocalizedText\x12\x0c\n\x04text\x18\x01 \x01(\t\"\xc6\x01\n\x10TranslationEntry\x12\x14\n\x0clanguage_key\x18\x01 \x01(\t\x12\x42\n\x0ctranslations\x18\x02 \x03(\x0b\x32,.artifact.TranslationEntry.TranslationsEntry\x12\n\n\x02id\x18\x03 \x01(\t\x1aL\n\x11TranslationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.artifact.LocalizedText:\x02\x38\x01\"L\n\x18MultilingualTranslations\x12\x30\n\x0ctranslations\x18\x01 \x03(\x0b\x32\x1a.artifact.TranslationEntry\"\x1d\n\x0bStylePrompt\x12\x0e\n\x06prompt\x18\x01 \x01(\t\"\xa5\x01\n\rChannelConfig\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12+\n\x0cstyle_prompt\x18\x02 \x01(\x0b\x32\x15.artifact.StylePrompt\x12$\n\x08greeting\x18\x03 \x01(\x0b\x32\x12.artifact.Greeting\x12/\n\x0esafety_filters\x18\x04 \x01(\x0b\x32\x17.artifact.ContentFilter\"\xd7\x01\n\x0cVoiceChannel\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\'\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.artifact.ChannelConfig\x12\x30\n\x0f\x62\x61rge_in_config\x18\x03 \x01(\x0b\x32\x17.artifact.BargeInConfig\x12/\n\x0elatency_config\x18\x04 \x01(\x0b\x32\x17.artifact.LatencyConfig\x12*\n\ndisclaimer\x18\x05 \x01(\x0b\x32\x16.artifact.IntroMessage\"J\n\x0eWebChatChannel\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\'\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.artifact.ChannelConfig\"]\n\x08\x43hannels\x12%\n\x05voice\x18\x01 \x01(\x0b\x32\x16.artifact.VoiceChannel\x12*\n\x08web_chat\x18\x02 \x01(\x0b\x32\x18.artifact.WebChatChannelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'artifact_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_COREARTIFACT'].fields_by_name['intro_message']._options = None
  _globals['_COREARTIFACT'].fields_by_name['intro_message']._serialized_options = b'\030\001'
  _globals['_COREARTIFACT'].fields_by_name['deployed_voices']._options = None
  _globals['_COREARTIFACT'].fields_by_name['deployed_voices']._serialized_options = b'\030\001'
  _globals['_FLOW'].fields_by_name['start_step']._options = None
  _globals['_FLOW'].fields_by_name['start_step']._serialized_options = b'\030\001'
  _globals['_FLOW'].fields_by_name['steps']._options = None
  _globals['_FLOW'].fields_by_name['steps']._serialized_options = b'\030\001'
  _globals['_FLOW'].fields_by_name['no_code_start_step']._options = None
  _globals['_FLOW'].fields_by_name['no_code_start_step']._serialized_options = b'\030\001'
  _globals['_FLOW'].fields_by_name['no_code_steps']._options = None
  _globals['_FLOW'].fields_by_name['no_code_steps']._serialized_options = b'\030\001'
  _globals['_MULTILINGUALAGENTSETTINGS_LANGUAGEBEHAVIORSENTRY']._options = None
  _globals['_MULTILINGUALAGENTSETTINGS_LANGUAGEBEHAVIORSENTRY']._serialized_options = b'8\001'
  _globals['_MULTILINGUALAGENTSETTINGS_GREETINGSENTRY']._options = None
  _globals['_MULTILINGUALAGENTSETTINGS_GREETINGSENTRY']._serialized_options = b'8\001'
  _globals['_TRANSLATIONENTRY_TRANSLATIONSENTRY']._options = None
  _globals['_TRANSLATIONENTRY_TRANSLATIONSENTRY']._serialized_options = b'8\001'
  _globals['_COREARTIFACT']._serialized_start=200
  _globals['_COREARTIFACT']._serialized_end=1606
  _globals['_VOICEWITHPROBABILITY']._serialized_start=1609
  _globals['_VOICEWITHPROBABILITY']._serialized_end=1746
  _globals['_ENTITIES']._serialized_start=1748
  _globals['_ENTITIES']._serialized_end=1794
  _globals['_ENTITY']._serialized_start=1797
  _globals['_ENTITY']._serialized_end=2409
  _globals['_VARIABLES']._serialized_start=2411
  _globals['_VARIABLES']._serialized_end=2461
  _globals['_VARIABLE']._serialized_start=2464
  _globals['_VARIABLE']._serialized_end=2636
  _globals['_NUMBERENTITYCONFIG']._serialized_start=2638
  _globals['_NUMBERENTITYCONFIG']._serialized_end=2706
  _globals['_ALPHANUMERICENTITYCONFIG']._serialized_start=2708
  _globals['_ALPHANUMERICENTITYCONFIG']._serialized_end=2749
  _globals['_MULTIPLEOPTIONSENTITYCONFIG']._serialized_start=2751
  _globals['_MULTIPLEOPTIONSENTITYCONFIG']._serialized_end=2797
  _globals['_DATEENTITYCONFIG']._serialized_start=2799
  _globals['_DATEENTITYCONFIG']._serialized_end=2874
  _globals['_PHONENUMBERENTITYCONFIG']._serialized_start=2876
  _globals['_PHONENUMBERENTITYCONFIG']._serialized_end=2924
  _globals['_TIMEENTITYCONFIG']._serialized_start=2926
  _globals['_TIMEENTITYCONFIG']._serialized_end=2982
  _globals['_NAMEENTITYCONFIG']._serialized_start=2984
  _globals['_NAMEENTITYCONFIG']._serialized_end=3002
  _globals['_ADDRESSENTITYCONFIG']._serialized_start=3004
  _globals['_ADDRESSENTITYCONFIG']._serialized_end=3025
  _globals['_FREETEXTENTITYCONFIG']._serialized_start=3027
  _globals['_FREETEXTENTITYCONFIG']._serialized_end=3049
  _globals['_DEPLOYEDVOICES']._serialized_start=3051
  _globals['_DEPLOYEDVOICES']._serialized_end=3149
  _globals['_CONVERSATIONLIMITS']._serialized_start=3151
  _globals['_CONVERSATIONLIMITS']._serialized_end=3225
  _globals['_VOICE']._serialized_start=3227
  _globals['_VOICE']._serialized_end=3320
  _globals['_ASR']._serialized_start=3322
  _globals['_ASR']._serialized_end=3425
  _globals['_TTSRULE']._serialized_start=3427
  _globals['_TTSRULE']._serialized_end=3519
  _globals['_MODEL']._serialized_start=3521
  _globals['_MODEL']._serialized_end=3596
  _globals['_ASSISTANTCONFIG']._serialized_start=3599
  _globals['_ASSISTANTCONFIG']._serialized_end=4129
  _globals['_RULES']._serialized_start=4132
  _globals['_RULES']._serialized_end=4269
  _globals['_PERSONALITY']._serialized_start=4271
  _globals['_PERSONALITY']._serialized_end=4370
  _globals['_ROLE']._serialized_start=4372
  _globals['_ROLE']._serialized_end=4434
  _globals['_KNOWLEDGEBASEMETADATA']._serialized_start=4437
  _globals['_KNOWLEDGEBASEMETADATA']._serialized_end=4566
  _globals['_KNOWLEDGEBASE']._serialized_start=4569
  _globals['_KNOWLEDGEBASE']._serialized_end=4810
  _globals['_FUNCTIONPARAMETER']._serialized_start=4812
  _globals['_FUNCTIONPARAMETER']._serialized_end=4880
  _globals['_DELAYRESPONSE']._serialized_start=4882
  _globals['_DELAYRESPONSE']._serialized_end=4932
  _globals['_LATENCYCONTROL']._serialized_start=4934
  _globals['_LATENCYCONTROL']._serialized_end=5041
  _globals['_FUNCTION']._serialized_start=5044
  _globals['_FUNCTION']._serialized_end=5268
  _globals['_FUNCTIONSDEPLOYMENT']._serialized_start=5270
  _globals['_FUNCTIONSDEPLOYMENT']._serialized_end=5331
  _globals['_HANDOFF']._serialized_start=5334
  _globals['_HANDOFF']._serialized_end=5686
  _globals['_VOICETUNINGSETTINGS']._serialized_start=5689
  _globals['_VOICETUNINGSETTINGS']._serialized_end=5940
  _globals['_SMSENVNUMBERS']._serialized_start=5942
  _globals['_SMSENVNUMBERS']._serialized_end=6009
  _globals['_SMSTEMPLATE']._serialized_start=6012
  _globals['_SMSTEMPLATE']._serialized_end=6265
  _globals['_FUNCTIONREFERENCE']._serialized_start=6267
  _globals['_FUNCTIONREFERENCE']._serialized_end=6328
  _globals['_STEPLAYOUT']._serialized_start=6330
  _globals['_STEPLAYOUT']._serialized_end=6364
  _globals['_FLOWSTEP']._serialized_start=6367
  _globals['_FLOWSTEP']._serialized_end=6664
  _globals['_FUNCTIONSTEP']._serialized_start=6666
  _globals['_FUNCTIONSTEP']._serialized_end=6751
  _globals['_FLOWSTARTSTEP']._serialized_start=6754
  _globals['_FLOWSTARTSTEP']._serialized_end=6917
  _globals['_STEP']._serialized_start=6920
  _globals['_STEP']._serialized_end=7074
  _globals['_NOCODESTEPCONDITIONDETAILS']._serialized_start=7076
  _globals['_NOCODESTEPCONDITIONDETAILS']._serialized_end=7188
  _globals['_NOCODESTEPREFERENCES']._serialized_start=7190
  _globals['_NOCODESTEPREFERENCES']._serialized_end=7267
  _globals['_EXITFLOWCONDITION']._serialized_start=7269
  _globals['_EXITFLOWCONDITION']._serialized_end=7343
  _globals['_FUNCTIONSTEPCONDITIONDETAILS']._serialized_start=7345
  _globals['_FUNCTIONSTEPCONDITIONDETAILS']._serialized_end=7432
  _globals['_FLOWSTEPCONDITION']._serialized_start=7434
  _globals['_FLOWSTEPCONDITION']._serialized_end=7533
  _globals['_NOCODESTEPCONDITION']._serialized_start=7535
  _globals['_NOCODESTEPCONDITION']._serialized_end=7636
  _globals['_FUNCTIONSTEPCONDITION']._serialized_start=7638
  _globals['_FUNCTIONSTEPCONDITION']._serialized_end=7743
  _globals['_CONDITION']._serialized_start=7746
  _globals['_CONDITION']._serialized_end=8015
  _globals['_NOCODESTEP']._serialized_start=8017
  _globals['_NOCODESTEP']._serialized_end=8127
  _globals['_STEPASRBIASINGCONFIG']._serialized_start=8130
  _globals['_STEPASRBIASINGCONFIG']._serialized_end=8394
  _globals['_STEPDTMFCONFIG']._serialized_start=8397
  _globals['_STEPDTMFCONFIG']._serialized_end=8580
  _globals['_FLOW']._serialized_start=8583
  _globals['_FLOW']._serialized_end=9044
  _globals['_FLOWS']._serialized_start=9046
  _globals['_FLOWS']._serialized_end=9088
  _globals['_AUDIOTOPLAY']._serialized_start=9090
  _globals['_AUDIOTOPLAY']._serialized_end=9147
  _globals['_INTROMESSAGE']._serialized_start=9150
  _globals['_INTROMESSAGE']._serialized_end=9433
  _globals['_AZURECONTENTFILTERCATEGORY']._serialized_start=9435
  _globals['_AZURECONTENTFILTERCATEGORY']._serialized_end=9501
  _globals['_AZURECONTENTFILTER']._serialized_start=9504
  _globals['_AZURECONTENTFILTER']._serialized_end=9743
  _globals['_CONTENTFILTER']._serialized_start=9745
  _globals['_CONTENTFILTER']._serialized_end=9844
  _globals['_LATENCYCONFIG']._serialized_start=9846
  _globals['_LATENCYCONFIG']._serialized_end=9887
  _globals['_BARGEINCONFIG']._serialized_start=9889
  _globals['_BARGEINCONFIG']._serialized_end=9921
  _globals['_STOPKEYWORDS']._serialized_start=9924
  _globals['_STOPKEYWORDS']._serialized_end=10215
  _globals['_ASRKEYPHRASE']._serialized_start=10217
  _globals['_ASRKEYPHRASE']._serialized_end=10265
  _globals['_VARIANT']._serialized_start=10268
  _globals['_VARIANT']._serialized_end=10459
  _globals['_VARIANTATTRIBUTE']._serialized_start=10462
  _globals['_VARIANTATTRIBUTE']._serialized_end=10707
  _globals['_ASRCORRECTION']._serialized_start=10710
  _globals['_ASRCORRECTION']._serialized_end=10844
  _globals['_ASRCORRECTIONREGULAREXPRESSIONS']._serialized_start=10846
  _globals['_ASRCORRECTIONREGULAREXPRESSIONS']._serialized_end=10954
  _globals['_APIINTEGRATIONS']._serialized_start=10956
  _globals['_APIINTEGRATIONS']._serialized_end=11025
  _globals['_APIINTEGRATION']._serialized_start=11028
  _globals['_APIINTEGRATION']._serialized_end=11192
  _globals['_ENVIRONMENTS']._serialized_start=11195
  _globals['_ENVIRONMENTS']._serialized_end=11357
  _globals['_APIINTEGRATIONCONFIG']._serialized_start=11359
  _globals['_APIINTEGRATIONCONFIG']._serialized_end=11424
  _globals['_APIINTEGRATIONOPERATION']._serialized_start=11426
  _globals['_APIINTEGRATIONOPERATION']._serialized_end=11511
  _globals['_LANGUAGE']._serialized_start=11513
  _globals['_LANGUAGE']._serialized_end=11537
  _globals['_LANGUAGES']._serialized_start=11539
  _globals['_LANGUAGES']._serialized_end=11646
  _globals['_LANGUAGEBEHAVIOR']._serialized_start=11648
  _globals['_LANGUAGEBEHAVIOR']._serialized_end=11714
  _globals['_GREETING']._serialized_start=11716
  _globals['_GREETING']._serialized_end=11774
  _globals['_MULTILINGUALAGENTSETTINGS']._serialized_start=11777
  _globals['_MULTILINGUALAGENTSETTINGS']._serialized_end=12119
  _globals['_MULTILINGUALAGENTSETTINGS_LANGUAGEBEHAVIORSENTRY']._serialized_start=11965
  _globals['_MULTILINGUALAGENTSETTINGS_LANGUAGEBEHAVIORSENTRY']._serialized_end=12049
  _globals['_MULTILINGUALAGENTSETTINGS_GREETINGSENTRY']._serialized_start=12051
  _globals['_MULTILINGUALAGENTSETTINGS_GREETINGSENTRY']._serialized_end=12119
  _globals['_LOCALIZEDTEXT']._serialized_start=12121
  _globals['_LOCALIZEDTEXT']._serialized_end=12150
  _globals['_TRANSLATIONENTRY']._serialized_start=12153
  _globals['_TRANSLATIONENTRY']._serialized_end=12351
  _globals['_TRANSLATIONENTRY_TRANSLATIONSENTRY']._serialized_start=12275
  _globals['_TRANSLATIONENTRY_TRANSLATIONSENTRY']._serialized_end=12351
  _globals['_MULTILINGUALTRANSLATIONS']._serialized_start=12353
  _globals['_MULTILINGUALTRANSLATIONS']._serialized_end=12429
  _globals['_STYLEPROMPT']._serialized_start=12431
  _globals['_STYLEPROMPT']._serialized_end=12460
  _globals['_CHANNELCONFIG']._serialized_start=12463
  _globals['_CHANNELCONFIG']._serialized_end=12628
  _globals['_VOICECHANNEL']._serialized_start=12631
  _globals['_VOICECHANNEL']._serialized_end=12846
  _globals['_WEBCHATCHANNEL']._serialized_start=12848
  _globals['_WEBCHATCHANNEL']._serialized_end=12922
  _globals['_CHANNELS']._serialized_start=12924
  _globals['_CHANNELS']._serialized_end=13017
# @@protoc_insertion_point(module_scope)
